@@ -1197,12 +1197,24 @@ void BambooTracker::checkNextPositionOfLastStep(int& endOrder, int& endStep) con
 	}
 }
 
-/********** Stream type **********/
-void BambooTracker::useSCCI(SoundInterfaceManager* manager)
+/********** Real chip interface **********/
+void BambooTracker::useSCCI(scci::SoundInterfaceManager* manager)
 {
 	opnaCtrl_->useSCCI(manager);
 }
 
+void BambooTracker::useC86CTL(C86ctlBase* base)
+{
+	opnaCtrl_->useC86CTL(base);
+}
+
+RealChipInterface BambooTracker::getRealChipinterface() const
+{
+	if (opnaCtrl_->isUsedSCCI()) return RealChipInterface::SCCI;
+	else if (opnaCtrl_->isUsedC86CTL()) return RealChipInterface::C86CTL;
+	else return RealChipInterface::NONE;
+}
+
 /********** Stream events **********/
 int BambooTracker::streamCountUp()
 {
