@@ -12,7 +12,7 @@ public:
 	CloneOrderCommand(std::weak_ptr<Module> mod, int songNum, int orderNum);
 	void redo() override;
 	void undo() override;
-	int getID() const override;
+	CommandId getID() const override;
 
 private:
 	std::weak_ptr<Module> mod_;
