@@ -10,7 +10,7 @@ public:
 	MoveOrderCommand(std::weak_ptr<Module> mod, int songNum, int orderNum, bool isUp);
 	void redo() override;
 	void undo() override;
-	int getID() const override;
+	CommandId getID() const override;
 
 private:
 	std::weak_ptr<Module> mod_;
