@@ -14,7 +14,7 @@ public:
 							   int endTrack, int endColumn, int endStep);
 	void redo() override;
 	void undo() override;
-	int getID() const override;
+	CommandId getID() const override;
 
 private:
 	std::weak_ptr<Module> mod_;
