@@ -13,7 +13,7 @@ public:
 											 std::vector<std::vector<std::string>> cells);
 	void redo() override;
 	void undo() override;
-	int getID() const override;
+	CommandId getID() const override;
 
 private:
 	std::weak_ptr<Module> mod_;
