@@ -3,15 +3,17 @@
 #include "abstract_command.hpp"
 #include <memory>
 #include "module.hpp"
+#include "misc.hpp"
 
 class SetEffectValueToStepCommand : public AbstractCommand
 {
 public:
 	SetEffectValueToStepCommand(std::weak_ptr<Module> mod, int songNum, int trackNum,
-								int orderNum, int stepNum, int n, int value, bool isFMReversed);
+								int orderNum, int stepNum, int n, int value,
+								EffectDisplayControl ctrl, bool secondEntry);
 	void redo() override;
 	void undo() override;
-	int getID() const override;
+	CommandId getID() const override;
 	bool mergeWith(const AbstractCommand* other) override;
 
 	int getSong() const;
@@ -19,12 +21,13 @@ public:
 	int getOrder() const;
 	int getStep() const;
 	int getN() const;
+	bool isSecondEntry() const;
 	int getEffectValue() const;
 
 private:
 	std::weak_ptr<Module> mod_;
 	int song_, track_, order_, step_, n_;
 	int val_, prevVal_;
-	bool isComplete_;
-	bool isFMReserved_;
+	EffectDisplayControl ctrl_;
+	bool isSecond_;
 };
