@@ -4,6 +4,7 @@
 #include <QApplication>
 #include <QClipboard>
 #include <QRegularExpression>
+#include "command_id.hpp"
 #include "gui/instrument_editor/instrument_editor_fm_form.hpp"
 #include "gui/instrument_editor/instrument_editor_ssg_form.hpp"
 
@@ -39,7 +40,7 @@ void RemoveInstrumentQtCommand::undo()
 	// KEEP CODE ORDER //
 	formMan_.lock()->add(num_, std::move(form), name_, source_);
 
-	item->setSizeHint(QSize(-1, 17));
+	item->setSizeHint(QSize(130, 17));
 	item->setData(Qt::UserRole, num_);
 	list_->insertItem(row_, item);
 	//----------//
@@ -62,5 +63,5 @@ void RemoveInstrumentQtCommand::redo()
 
 int RemoveInstrumentQtCommand::id() const
 {
-	return 0x11;
+	return CommandId::RemoveInstrument;
 }
