@@ -1,4 +1,5 @@
 #include "clone_order_qt_command.hpp"
+#include "command_id.hpp"
 
 CloneOrderQtCommand::CloneOrderQtCommand(OrderListPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -9,16 +10,16 @@ CloneOrderQtCommand::CloneOrderQtCommand(OrderListPanel* panel, QUndoCommand* pa
 void CloneOrderQtCommand::redo()
 {
 	panel_->onOrderEdited();
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 void CloneOrderQtCommand::undo()
 {
 	panel_->onOrderEdited();
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 int CloneOrderQtCommand::id() const
 {
-	return 0x47;
+	return CommandId::CloneOrder;
 }
