@@ -1,4 +1,5 @@
 #include "clone_patterns_qt_command.hpp"
+#include "command_id.hpp"
 
 ClonePatternsQtCommand::ClonePatternsQtCommand(OrderListPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -9,16 +10,16 @@ ClonePatternsQtCommand::ClonePatternsQtCommand(OrderListPanel* panel, QUndoComma
 void ClonePatternsQtCommand::redo()
 {
 	panel_->onOrderEdited();
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 void ClonePatternsQtCommand::undo()
 {
 	panel_->onOrderEdited();
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 int ClonePatternsQtCommand::id() const
 {
-	return 0x46;
+	return CommandId::ClonePatterns;
 }
