@@ -1,4 +1,5 @@
 #include "insert_order_below_qt_command.hpp"
+#include "command_id.hpp"
 
 InsertOrderBelowQtCommand::InsertOrderBelowQtCommand(OrderListPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -9,16 +10,16 @@ InsertOrderBelowQtCommand::InsertOrderBelowQtCommand(OrderListPanel* panel, QUnd
 void InsertOrderBelowQtCommand::redo()
 {
 	panel_->onOrderEdited();
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 void InsertOrderBelowQtCommand::undo()
 {
 	panel_->onOrderEdited();
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 int InsertOrderBelowQtCommand::id() const
 {
-	return 0x41;
+	return CommandId::InsertOrderBelow;
 }
