@@ -1,4 +1,5 @@
 #include "move_order_qt_command.hpp"
+#include "command_id.hpp"
 
 MoveOrderQtCommand::MoveOrderQtCommand(OrderListPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -9,16 +10,16 @@ MoveOrderQtCommand::MoveOrderQtCommand(OrderListPanel* panel, QUndoCommand* pare
 void MoveOrderQtCommand::redo()
 {
 	panel_->onOrderEdited();
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 void MoveOrderQtCommand::undo()
 {
 	panel_->onOrderEdited();
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 int MoveOrderQtCommand::id() const
 {
-	return 0x45;
+	return CommandId::MoveOrder;
 }
