@@ -1,4 +1,5 @@
 #include "paste_copied_data_to_order_qt_command.hpp"
+#include "command_id.hpp"
 
 PasteCopiedDataToOrderQtCommand::PasteCopiedDataToOrderQtCommand(OrderListPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -9,16 +10,16 @@ PasteCopiedDataToOrderQtCommand::PasteCopiedDataToOrderQtCommand(OrderListPanel*
 void PasteCopiedDataToOrderQtCommand::redo()
 {
 	panel_->onOrderEdited();
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 void PasteCopiedDataToOrderQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 	panel_->onOrderEdited();
 }
 
 int PasteCopiedDataToOrderQtCommand::id() const
 {
-   return 0x43;
+   return CommandId::PasteCopiedDataToOrder;
 }
