@@ -1,4 +1,5 @@
 #include "decrease_note_octave_in_pattern_qt_command.hpp"
+#include "command_id.hpp"
 
 DecreaseNoteOctaveInPatternQtCommand::DecreaseNoteOctaveInPatternQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ DecreaseNoteOctaveInPatternQtCommand::DecreaseNoteOctaveInPatternQtCommand(Patte
 
 void DecreaseNoteOctaveInPatternQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 void DecreaseNoteOctaveInPatternQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 int DecreaseNoteOctaveInPatternQtCommand::id() const
 {
-	return 0x33;
+	return CommandId::DecreaseNoteOctaveInPattern;
 }
