@@ -1,4 +1,5 @@
 #include "delete_previous_step_qt_command.hpp"
+#include "command_id.hpp"
 
 DeletePreviousStepQtCommand::DeletePreviousStepQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ DeletePreviousStepQtCommand::DeletePreviousStepQtCommand(PatternEditorPanel* pan
 
 void DeletePreviousStepQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 void DeletePreviousStepQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 int DeletePreviousStepQtCommand::id() const
 {
-	return 0x2c;
+	return CommandId::DeletePreviousStep;
 }
