@@ -1,4 +1,5 @@
 #include "erase_effect_in_step_qt_command.hpp"
+#include "command_id.hpp"
 
 EraseEffectInStepQtCommand::EraseEffectInStepQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ EraseEffectInStepQtCommand::EraseEffectInStepQtCommand(PatternEditorPanel* panel
 
 void EraseEffectInStepQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 void EraseEffectInStepQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 int EraseEffectInStepQtCommand::id() const
 {
-	return 0x28;
+	return CommandId::EraseEffectInStep;
 }
