@@ -1,4 +1,5 @@
 #include "erase_instrument_in_step_qt_command.hpp"
+#include "command_id.hpp"
 
 EraseInstrumentInStepQtCommand::EraseInstrumentInStepQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ EraseInstrumentInStepQtCommand::EraseInstrumentInStepQtCommand(PatternEditorPane
 
 void EraseInstrumentInStepQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 void EraseInstrumentInStepQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 int EraseInstrumentInStepQtCommand::id() const
 {
-	return 0x24;
+	return CommandId::EraseInstrumentInStep;
 }
