@@ -1,4 +1,5 @@
 #include "erase_step_qt_command.hpp"
+#include "command_id.hpp"
 
 EraseStepQtCommand::EraseStepQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ EraseStepQtCommand::EraseStepQtCommand(PatternEditorPanel* panel, QUndoCommand*
 
 void EraseStepQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 void EraseStepQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 int EraseStepQtCommand::id() const
 {
-	return 0x22;
+	return CommandId::EraseStep;
 }
