@@ -1,4 +1,5 @@
 #include "erase_volume_in_step_qt_command.hpp"
+#include "command_id.hpp"
 
 EraseVolumeInStepQtCommand::EraseVolumeInStepQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ EraseVolumeInStepQtCommand::EraseVolumeInStepQtCommand(PatternEditorPanel* panel
 
 void EraseVolumeInStepQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 void EraseVolumeInStepQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 int EraseVolumeInStepQtCommand::id() const
 {
-	return 0x26;
+	return CommandId::EraseVolumeInStep;
 }
