@@ -1,4 +1,5 @@
 #include "increase_note_key_in_pattern_qt_command.hpp"
+#include "command_id.hpp"
 
 IncreaseNoteKeyInPatternQtCommand::IncreaseNoteKeyInPatternQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ IncreaseNoteKeyInPatternQtCommand::IncreaseNoteKeyInPatternQtCommand(PatternEdit
 
 void IncreaseNoteKeyInPatternQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 void IncreaseNoteKeyInPatternQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 int IncreaseNoteKeyInPatternQtCommand::id() const
 {
-	return 0x30;
+	return CommandId::IncreaseNoteKeyInPattern;
 }
