@@ -1,4 +1,5 @@
 #include "interpolate_pattern_qt_command.hpp"
+#include "command_id.hpp"
 
 InterpolatePatternQtCommand::InterpolatePatternQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ InterpolatePatternQtCommand::InterpolatePatternQtCommand(PatternEditorPanel* pan
 
 void InterpolatePatternQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 void InterpolatePatternQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 int InterpolatePatternQtCommand::id() const
 {
-	return 0x36;
+	return CommandId::InterpolatePattern;
 }
