@@ -1,4 +1,5 @@
 #include "paste_mix_copied_data_to_pattern_qt_command.hpp"
+#include "command_id.hpp"
 
 PasteMixCopiedDataToPatternQtCommand::PasteMixCopiedDataToPatternQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ PasteMixCopiedDataToPatternQtCommand::PasteMixCopiedDataToPatternQtCommand(Patte
 
 void PasteMixCopiedDataToPatternQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 void PasteMixCopiedDataToPatternQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 int PasteMixCopiedDataToPatternQtCommand::id() const
 {
-	return 0x2f;
+	return CommandId::PasteMixCopiedDataToPattern;
 }
