@@ -1,4 +1,5 @@
 #include "paste_overwrite_copied_data_to_pattern_qt_command.hpp"
+#include "command_id.hpp"
 
 PasteOverwriteCopiedDataToPatternQtCommand::PasteOverwriteCopiedDataToPatternQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ PasteOverwriteCopiedDataToPatternQtCommand::PasteOverwriteCopiedDataToPatternQtC
 
 void PasteOverwriteCopiedDataToPatternQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 void PasteOverwriteCopiedDataToPatternQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged(true);
 }
 
 int PasteOverwriteCopiedDataToPatternQtCommand::id() const
 {
-	return 0x3a;
+	return CommandId::PasteOverwriteCopiedDataToPattern;
 }
