@@ -1,4 +1,5 @@
 #include "set_echo_buffer_access_qt_command.hpp"
+#include "command_id.hpp"
 
 SetEchoBufferAccessQtCommand::SetEchoBufferAccessQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ SetEchoBufferAccessQtCommand::SetEchoBufferAccessQtCommand(PatternEditorPanel* p
 
 void SetEchoBufferAccessQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 void SetEchoBufferAccessQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 int SetEchoBufferAccessQtCommand::id() const
 {
-	return 0x36;
+	return CommandId::SetEchoBufferAccess;
 }
