@@ -1,4 +1,5 @@
 #include "set_key_on_to_step_qt_command.hpp"
+#include "command_id.hpp"
 
 SetKeyOnToStepQtCommand::SetKeyOnToStepQtCommand(PatternEditorPanel* panel, QUndoCommand* parent)
 	: QUndoCommand(parent),
@@ -8,15 +9,15 @@ SetKeyOnToStepQtCommand::SetKeyOnToStepQtCommand(PatternEditorPanel* panel, QUnd
 
 void SetKeyOnToStepQtCommand::redo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 void SetKeyOnToStepQtCommand::undo()
 {
-	panel_->update();
+	panel_->redrawByPatternChanged();
 }
 
 int SetKeyOnToStepQtCommand::id() const
 {
-	return 0x20;
+	return CommandId::SetKeyOnToStep;
 }
