@@ -1,9 +1,7 @@
 #include "fm_operator_table.hpp"
 #include "ui_fm_operator_table.h"
 #include <QString>
-#include <QGraphicsScene>
 #include <QPen>
-#include <QBrush>
 #include <QMenu>
 #include <QClipboard>
 #include "gui/event_guard.hpp"
@@ -19,6 +17,25 @@ FMOperatorTable::FMOperatorTable(QWidget *parent) :
 	ui->groupBox->setContextMenuPolicy(Qt::CustomContextMenu);
 
 	// Init sliders
+	ui->arSlider->setText("AR");
+	ui->arSlider->setMaximum(31);
+	ui->drSlider->setText("DR");
+	ui->drSlider->setMaximum(31);
+	ui->srSlider->setText("SR");
+	ui->srSlider->setMaximum(31);
+	ui->rrSlider->setText("RR");
+	ui->rrSlider->setMaximum(15);
+	ui->slSlider->setText("SL");
+	ui->slSlider->setMaximum(15);
+	ui->tlSlider->setText("TL");
+	ui->tlSlider->setMaximum(127);
+	ui->ksSlider->setText("KS");
+	ui->ksSlider->setMaximum(3);
+	ui->mlSlider->setText("ML");
+	ui->mlSlider->setMaximum(15);
+	ui->dtSlider->setText("DT");
+	ui->dtSlider->setMaximum(7);
+
 	sliderMap_ = {
 		{ Ui::FMOperatorParameter::AR, ui->arSlider },
 		{ Ui::FMOperatorParameter::DR, ui->drSlider },
@@ -31,13 +48,7 @@ FMOperatorTable::FMOperatorTable(QWidget *parent) :
 		{ Ui::FMOperatorParameter::DT, ui->dtSlider }
 	};
 
-	QString name[] = { "AR", "DR", "SR", "RR", "SL", "TL", "KS", "ML", "DT"};
-	int maxValue[] = { 31, 31, 31, 15, 15, 127, 3, 15, 7};
-
-	int n = 0;
 	for (auto& pair : sliderMap_) {
-		pair.second->setText(name[n]);
-		pair.second->setMaximum(maxValue[n]);
 		if (pair.second == ui->dtSlider) {
 			QObject::connect(pair.second, &LabeledVerticalSlider::valueChanged,
 							 this, [&](int value) {
@@ -60,7 +71,6 @@ FMOperatorTable::FMOperatorTable(QWidget *parent) :
 				if (!isIgnoreEvent_) emit operatorValueChanged(pair.first, value);
 			});
 		}
-		++n;
 	}
 
 	ui->ssgegSlider->setEnabled(false);
@@ -72,9 +82,9 @@ FMOperatorTable::FMOperatorTable(QWidget *parent) :
 		if (!isIgnoreEvent_) emit operatorValueChanged(Ui::FMOperatorParameter::SSGEG, value);
 	});
 
-	// Init graph
-	auto scene = new QGraphicsScene(0, 0, 201, 128, ui->envelopeGraphicsView);
-	ui->envelopeGraphicsView->setScene(scene);
+	envmap_ = std::make_unique<QPixmap>();
+
+	ui->envFrame->installEventFilter(this);
 }
 
 FMOperatorTable::~FMOperatorTable()
@@ -95,7 +105,7 @@ void FMOperatorTable::setColorPalette(std::shared_ptr<ColorPalette> palette)
 void FMOperatorTable::setOperatorNumber(int n)
 {
 	number_ = n;
-	ui->groupBox->setTitle(tr("Operator ") + QString::number(n + 1));
+	ui->groupBox->setTitle(tr("Operator %1").arg(n + 1));
 }
 
 int FMOperatorTable::operatorNumber() const
@@ -190,6 +200,19 @@ QString FMOperatorTable::toString() const
 	return str;
 }
 
+bool FMOperatorTable::eventFilter(QObject* obj, QEvent* event)
+{
+	if (obj == ui->envFrame) {
+		if (event->type() == QEvent::Paint) {
+			QPainter painter(ui->envFrame);
+			painter.eraseRect(ui->envFrame->rect());
+			painter.drawPixmap(ui->envFrame->rect(), *envmap_.get(), envmap_->rect());
+		}
+	}
+
+	return false;
+}
+
 void FMOperatorTable::showEvent(QShowEvent* event)
 {
 	Q_UNUSED(event)
@@ -201,165 +224,208 @@ void FMOperatorTable::resizeEvent(QResizeEvent* event)
 {
 	Q_UNUSED(event)
 	resizeGraph();
+	repaintGraph();
 }
 
 void FMOperatorTable::resizeGraph()
 {
-	ui->envelopeGraphicsView->fitInView(ui->envelopeGraphicsView->scene()->sceneRect());
+	envmap_ = std::make_unique<QPixmap>(ui->envFrame->size());
+	xr_ = (envmap_->width() - (ENV_LINE_W_ + 1) * 2.) / ENV_W_;
+	yr_ = (envmap_->height() - (ENV_LINE_W_ + 1) * 2.) / ENV_H_;
 }
 
 void FMOperatorTable::repaintGraph()
 {
 	if (!palette_) return;
 
-	auto scene = ui->envelopeGraphicsView->scene();
-	double envHeight = ui->ssgegCheckBox->isChecked() ? (scene->height() - 40) : scene->height();
-	double startx = 0;
+	QPointF p0, p1, p2, p3, p4;
+	const double marginHorizon = 100;
+	const double marginAr = 50;
+	const double marginDr = 150;
+	const double marginSr = 400;
 
-	double tly, tlx;
-	if (ui->arSlider->value()) {
-		tly = (127 - ui->tlSlider->value()) / 127.0 * envHeight;
-	}
-	else {
-		tly = 0;
-	}
-	tlx = 50 * (31 - ui->arSlider->value()) / 31 * tly / envHeight;
+	if (ui->arSlider->value() && ui->tlSlider->value() < 127) {
+		p1.setY(127 - ui->tlSlider->value());
+		if (ui->arSlider->value() < 31) {
+			double ar = 127. / (marginAr * (31 - ui->arSlider->value()) / 30.);
+			p1.setX(p1.y() / ar);
+		}
 
-	double sly, slx;
-	if (ui->drSlider->value()) {
-		sly = (15 - ui->slSlider->value()) / 15.0 * tly;
-		slx = 100 / envHeight * (31 - ui->drSlider->value()) / 31 * (tly - sly);
-	}
-	else {
-		sly = tly;
-		if (ui->slSlider->value()) {
-			slx = 100 * sly / envHeight;
+		if (ui->drSlider->value()) {
+			p2.setY(p1.y() * (1. - ui->slSlider->value() / 15.));
+			if (ui->drSlider->value() == 31) {
+				p2.setX(p1.x());
+				if (ui->slSlider->value() == 15) {
+					p3 = p2;
+				}
+				else {
+					if (ui->srSlider->value()) {
+						p3.setY(p2.y() / 2.);
+						if (ui->srSlider->value() == 31) {
+							p3.setX(p2.x());
+						}
+						else {
+							double sr = 127. / (marginSr * (31 - ui->srSlider->value()) / 30.);
+							p3.setX(p2.x() + p3.y() / 2. / sr);
+						}
+					}
+					else {
+						p3 = { p2.x() + ((ui->slSlider->value() == 15) ? 0 : marginHorizon), p2.y() };
+					}
+				}
+			}
+			else {
+				double dr = 127. / (marginDr * (31 - ui->drSlider->value()) / 30.);
+				p2.setX(p1.x() + (p1.y() - p2.y()) / dr);
+				if (ui->srSlider->value()) {
+					p3.setY(p2.y() / 2.);
+					if (ui->srSlider->value() == 31) {
+						p3.setX(p2.x());
+					}
+					else {
+						double sr = 127. / (marginSr * (31 - ui->srSlider->value()) / 30.);
+						p3.setX(p2.x() + p3.y() / 2. / sr);
+					}
+				}
+				else {
+					p3 = { p2.x() + ((ui->slSlider->value() == 15) ? 0 : marginHorizon), p2.y() };
+				}
+			}
 		}
 		else {
-			slx = 0;
+			if (ui->slSlider->value()) {
+				p2 = { p1.x() + marginHorizon, p1.y() };
+				p3 = p2;
+			}
+			else {
+				p2 = p1;
+				if (ui->srSlider->value()) {
+					p3.setY(p2.y() / 2.);
+					if (ui->srSlider->value() == 31) {
+						p3.setX(p2.x());
+					}
+					else {
+						double sr = 127. / (marginSr * (31 - ui->srSlider->value()) / 30.);
+						p3.setX(p2.x() + p3.y() / 2. / sr);
+					}
+				}
+				else {
+					p3 = { p2.x() + marginHorizon, p2.y() };
+				}
+			}
 		}
-	}
-	slx += tlx;
-	tly = envHeight - tly;
 
-	double rry, rrx;
-	if (!ui->drSlider->value() && ui->slSlider->value()) {
-		rry = sly;
-		rrx = 0;
-	}
-	else {
-		if (ui->srSlider->value()) {
-			rry = 0.5 * sly;
-			rrx = 100 / envHeight * (31 - ui->srSlider->value()) / 31 * (sly - rry);
+		if (!ui->rrSlider->value()) {
+			p4 = { ENV_W_, p3.y() };
+		}
+		else if (ui->rrSlider->value() == 31) {
+			p4.setX(p3.x());
 		}
 		else {
-			rry = sly;
-			rrx = 100;
+			double rr = 127. / (marginAr * (15 - ui->rrSlider->value()) / 14.);
+			p4.setX(p3.x() + p3.y() / rr);
 		}
 	}
-	rrx += slx;
-	sly = envHeight - sly;
 
-	double endy, endx;
-	if (ui->rrSlider->value()) {
-		endy = 0;
-		endx = (100 * rry / envHeight) * (15 - ui->rrSlider->value()) / 15 + rrx;
-	}
-	else {
-		endy = rry;
-		endx = 200;
-	}
-	rry = envHeight - rry;
-	endy = envHeight - endy;
+	double envHeight = ui->ssgegCheckBox->isChecked() ? (ENV_H_ - SSGEG_H_) : ENV_H_;
+	double envHrate = envHeight / 127.;
+	p0.setY((127. - p0.y()) * envHrate);
+	p1.setY((127. - p1.y()) * envHrate);
+	p2.setY((127. - p2.y()) * envHrate);
+	p3.setY((127. - p3.y()) * envHrate);
+	p4.setY((127. - p4.y()) * envHrate);
 
-	scene->clear();
-	scene->addRect(0, 0, scene->width(), scene->height(),
-				   QPen(palette_->instFMEnvBackColor), QBrush(palette_->instFMEnvBackColor));
+	envmap_->fill(palette_->instFMEnvBackColor);
+	QPainter painter(envmap_.get());
 
-	auto linePen = QPen(QBrush(palette_->instFMEnvLine1Color), 2);
-	scene->addLine(startx, envHeight, tlx, tly, linePen);
-	scene->addLine(tlx, tly, slx, sly, linePen);
-	scene->addLine(slx, sly, rrx, rry, linePen);
-	scene->addLine(rrx, rry, endx, endy, linePen);
+	painter.setPen(QPen(palette_->instFMEnvGridColor, ENV_LINE_T_));
+	drawLine(painter, p1.x(), 0, p1.x(), envHeight);
+	drawLine(painter, p2.x(), 0, p2.x(), envHeight);
+	drawLine(painter, p3.x(), 0, p3.x(), envHeight);
 
-	auto cclPen = QPen(palette_->instFMEnvCirclePenColor);
-	auto cclBrush = QBrush(palette_->instFMEnvCircleBrushColor);
-	scene->addEllipse(tlx-1, tly, 4, 4, cclPen, cclBrush);
-	scene->addEllipse(slx-1, sly, 4, 4, cclPen, cclBrush);
-	scene->addEllipse(rrx-1, rry, 4, 4, cclPen, cclBrush);
+	painter.setPen(QPen(palette_->instFMEnvLine1Color, ENV_LINE_W_));
+	drawLines(painter, { p0, p1, p2, p3 });
+	painter.setPen(QPen(palette_->instFMEnvLine2Color, ENV_LINE_W_));
+	drawLine(painter, p3, p4);
 
 	if (ui->ssgegCheckBox->isChecked()) {
-		double seph = scene->height() - 39;
-		scene->addLine(0, seph, 200, seph, QPen(palette_->instFMEnvBorderColor));
-		double toph = seph + 2;
-		double both = scene->height();
-		linePen.setBrush(palette_->instFMEnvLine2Color);
+		const double seph = envHeight + 1;
+		painter.setPen(QPen(palette_->instFMEnvBorderColor, ENV_LINE_T_));
+		drawLine(painter, 0, seph, ENV_W_, seph);
+
+		const double toph = seph + 2;
+		const double both = ENV_H_;
+		const double horsec = ENV_W_ / 5.;
+		const double dhorsec = horsec * 2;
+		painter.setPen(QPen(palette_->instFMEnvLine3Color, ENV_LINE_W_));
 		switch (ui->ssgegSlider->value()) {
 		case 0:
 		{
 			for (int i = 0; i < 5; ++i) {
-				scene->addLine(40 * i, both, 40 * i, toph, linePen);
-				scene->addLine(40 * i, toph, 40 * (i + 1), both, linePen);
+				drawLine(painter, horsec * i, both, horsec * i, toph);
+				drawLine(painter, horsec * i, toph, horsec * (i + 1), both);
 			}
 		}
 			break;
 		case 1:
 		{
-			scene->addLine(0, both, 0, toph, linePen);
-			scene->addLine(0, toph, 40, both, linePen);
-			scene->addLine(40, both, 200, both, linePen);
+			drawLine(painter, 0, both, 0, toph);
+			drawLine(painter, 0, toph, horsec, both);
+			drawLine(painter, horsec, both, ENV_W_, both);
 		}
 			break;
 		case 2:
 		{
-			scene->addLine(0, both, 0, toph, linePen);
-			scene->addLine(0, toph, 40, both, linePen);
+			drawLine(painter, 0, both, 0, toph);
+			drawLine(painter, 0, toph, horsec, both);
 			for (int i = 0; i < 2; ++i) {
-				scene->addLine(40 + 80 * i, both, 80 + 80 * i, toph, linePen);
-				scene->addLine(80 + 80 * i, toph, 40 + 80 * (i + 1), both, linePen);
+				drawLine(painter, horsec + dhorsec * i, both, dhorsec + dhorsec * i, toph);
+				drawLine(painter, dhorsec + dhorsec * i, toph, horsec + dhorsec * (i + 1), both);
 			}
 		}
 			break;
 		case 3:
 		{
-			scene->addLine(0, both, 0, toph, linePen);
-			scene->addLine(0, toph, 40, both, linePen);
-			scene->addLine(40, both, 40, toph, linePen);
-			scene->addLine(40, toph, 200, toph, linePen);
+			drawLine(painter, 0, both, 0, toph);
+			drawLine(painter, 0, toph, horsec, both);
+			drawLine(painter, horsec, both, horsec, toph);
+			drawLine(painter, horsec, toph, ENV_W_, toph);
 		}
 			break;
 		case 4:
 		{
 			for (int i = 0; i < 5; ++i) {
-				scene->addLine(40 * i, both, 40 * (i + 1), toph, linePen);
-				scene->addLine(40 * (i + 1), toph, 40 * (i + 1), both, linePen);
+				drawLine(painter, horsec * i, both, horsec * (i + 1), toph);
+				drawLine(painter, horsec * (i + 1), toph, horsec * (i + 1), both);
 			}
 		}
 			break;
 		case 5:
 		{
-			scene->addLine(0, both, 40, toph, linePen);
-			scene->addLine(40, toph, 200, toph, linePen);
+			drawLine(painter, 0, both, horsec, toph);
+			drawLine(painter, horsec, toph, ENV_W_, toph);
 		}
 			break;
 		case 6:
 		{
 			for (int i = 0; i < 2; ++i) {
-				scene->addLine(80 * i, both, 40 + 80 * i, toph, linePen);
-				scene->addLine(40 + 80 * i, toph, 80 * (i + 1), both, linePen);
+				drawLine(painter, dhorsec * i, both, horsec + dhorsec * i, toph);
+				drawLine(painter, horsec + dhorsec * i, toph, dhorsec * (i + 1), both);
 			}
-			scene->addLine(160, both, 200, toph, linePen);
+			drawLine(painter, dhorsec * 2, both, ENV_W_, toph);
 		}
 			break;
 		case 7:
 		{
-			scene->addLine(0, both, 40, toph, linePen);
-			scene->addLine(40, toph, 40, both, linePen);
-			scene->addLine(40, both, 200, both, linePen);
+			drawLine(painter, 0, both, horsec, toph);
+			drawLine(painter, horsec, toph, horsec, both);
+			drawLine(painter, horsec, both, ENV_W_, both);
 		}
 			break;
 		}
 	}
+
+	ui->envFrame->repaint();
 }
 
 void FMOperatorTable::on_ssgegCheckBox_stateChanged(int arg1)
@@ -367,13 +433,10 @@ void FMOperatorTable::on_ssgegCheckBox_stateChanged(int arg1)
 	Q_UNUSED(arg1)
 	if (ui->ssgegCheckBox->isChecked()) {
 		ui->ssgegSlider->setEnabled(true);
-		ui->arSlider->setValue(31);
-		ui->arSlider->setEnabled(false);
 		if (!isIgnoreEvent_) emit operatorValueChanged(Ui::FMOperatorParameter::SSGEG, ui->ssgegSlider->value());
 	}
 	else {
 		ui->ssgegSlider->setEnabled(false);
-		ui->arSlider->setEnabled(true);
 		if (!isIgnoreEvent_) emit operatorValueChanged(Ui::FMOperatorParameter::SSGEG, -1);
 	}
 	repaintGraph();
