@@ -5,7 +5,7 @@
 #include <QWidget>
 #include <QString>
 #include <memory>
-#include <map>
+#include <unordered_map>
 #include "instrument/envelope_fm.hpp"
 #include "misc.hpp"
 
@@ -29,6 +29,8 @@ public:
 	void setFormInstrumentName(int n, QString name);
 	SoundSource getFormInstrumentSoundSource(int n) const;
 
+	int checkActivatedFormNumber() const;
+
 public slots:
 	void onInstrumentFMEnvelopeParameterChanged(int envNum, int fromInstNum);
 	void onInstrumentFMEnvelopeNumberChanged();
@@ -53,7 +55,7 @@ public slots:
 	void onInstrumentSSGPitchNumberChanged();
 
 private:
-	std::map<int, std::unique_ptr<QWidget>> map_;
+	std::unordered_map<int, std::unique_ptr<QWidget>> map_;
 };
 
 
