@@ -3,10 +3,13 @@
 #include <vector>
 #include <utility>
 
-ModulePropertiesDialog::ModulePropertiesDialog(std::weak_ptr<BambooTracker> core, QWidget *parent) :
-	QDialog(parent),
-	ui(new Ui::ModulePropertiesDialog),
-	bt_(core)
+ModulePropertiesDialog::ModulePropertiesDialog(std::weak_ptr<BambooTracker> core, double configFmMixer,
+											   double configSsgMixer, QWidget *parent)
+	: QDialog(parent),
+	  ui(new Ui::ModulePropertiesDialog),
+	  bt_(core),
+	  configFmMixer_(configFmMixer),
+	  configSsgMixer_(configSsgMixer)
 {
 	ui->setupUi(this);
 
@@ -20,6 +23,16 @@ ModulePropertiesDialog::ModulePropertiesDialog(std::weak_ptr<BambooTracker> core
 	default:	ui->customTickFreqRadioButton->setChecked(true);	break;
 	}
 
+	MixerType mixType = core.lock()->getModuleMixerType();
+	if (mixType == MixerType::UNSPECIFIED) {
+		ui->mixerGroupBox->setChecked(false);
+	}
+	else {
+		ui->mixerGroupBox->setChecked(true);
+		ui->mixerTypeComboBox->setCurrentIndex(static_cast<int>(mixType) - 1);
+	}
+	setCustomMixerLevels(core.lock()->getModuleCustomMixerFMLevel(), core.lock()->getModuleCustomMixerSSGLevel());
+
 	ui->songTreeWidget->setColumnCount(3);
 	ui->songTreeWidget->setHeaderLabels({ tr("Number"), tr("Title"), tr("Song type") });
 	ui->songTreeWidget->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
@@ -30,8 +43,8 @@ ModulePropertiesDialog::ModulePropertiesDialog(std::weak_ptr<BambooTracker> core
 				   core.lock()->getSongStyle(i).type, i);
 	}
 
-	ui->insertTypeComboBox->addItem(tr("Standard"), static_cast<int>(SongType::STD));
-	ui->insertTypeComboBox->addItem(tr("FM3ch expanded"), static_cast<int>(SongType::FMEX));
+	ui->insertTypeComboBox->addItem(tr("Standard"), static_cast<int>(SongType::Standard));
+	ui->insertTypeComboBox->addItem(tr("FM3ch expanded"), static_cast<int>(SongType::FM3chExpanded));
 }
 
 ModulePropertiesDialog::~ModulePropertiesDialog()
@@ -46,8 +59,8 @@ void ModulePropertiesDialog::insertSong(int row, QString title, SongType type, i
 	item->setData(0, Qt::UserRole, prevNum);
 	item->setText(1, title);
 	switch (type) {
-	case SongType::STD:		item->setText(2, tr("Standard"));		break;
-	case SongType::FMEX:	item->setText(2, tr("FM3ch expanded"));	break;
+	case SongType::Standard:		item->setText(2, tr("Standard"));		break;
+	case SongType::FM3chExpanded:	item->setText(2, tr("FM3ch expanded"));	break;
 	}
 	item->setData(2, Qt::UserRole, static_cast<int>(type));
 	ui->songTreeWidget->insertTopLevelItem(row, item);
@@ -92,6 +105,15 @@ void ModulePropertiesDialog::swapset(int aboveRow, int belowRow)
 	}
 }
 
+void ModulePropertiesDialog::setCustomMixerLevels(double fm, double ssg)
+{
+	fmMixer_ = fm;
+	ssgMixer_ = ssg;
+
+	ui->customMixerFMLevelLabel->setText(QString::asprintf("%+.1fdB", fmMixer_));
+	ui->customMixerSSGLevelLabel->setText(QString::asprintf("%+.1fdB", ssgMixer_));
+}
+
 /******************************/
 void ModulePropertiesDialog::on_upToolButton_clicked()
 {
@@ -155,6 +177,19 @@ void ModulePropertiesDialog::onAccepted()
 	else tickFreq = static_cast<unsigned int>(ui->customTickFreqSpinBox->value());
 	bt_.lock()->setModuleTickFrequency(tickFreq);
 
+	// Set mixer
+	if (ui->mixerGroupBox->isChecked()) {
+		auto mixType = static_cast<MixerType>(ui->mixerTypeComboBox->currentIndex() + 1);
+		bt_.lock()->setModuleMixerType(mixType);
+		if (mixType == MixerType::CUSTOM) {
+			bt_.lock()->setModuleCustomMixerFMLevel(fmMixer_);
+			bt_.lock()->setModuleCustomMixerSSGLevel(ssgMixer_);
+		}
+	}
+	else {
+		bt_.lock()->setModuleMixerType(MixerType::UNSPECIFIED);
+	}
+
 	auto* tree = ui->songTreeWidget;
 	std::vector<int> newSongNums;
 
@@ -176,3 +211,13 @@ void ModulePropertiesDialog::onAccepted()
 	// Sort songs
 	bt_.lock()->sortSongs(std::move(newSongNums));
 }
+
+void ModulePropertiesDialog::on_mixerTypeComboBox_currentIndexChanged(int index)
+{
+	ui->mixerCustomGroupBox->setEnabled(index == 0);
+}
+
+void ModulePropertiesDialog::on_customMixerSetPushButton_clicked()
+{
+	setCustomMixerLevels(configFmMixer_, configSsgMixer_);
+}
