@@ -3,20 +3,30 @@
 
 PatternEditor::PatternEditor(QWidget *parent) :
 	QFrame(parent),
-	ui(new Ui::PatternEditor)
+	ui(new Ui::PatternEditor),
+	freezed_(false),
+	songLoaded_(false),
+	hScrollCellMove_(true)
 {
 	ui->setupUi(this);
 
 	installEventFilter(this);
 	ui->panel->installEventFilter(this);
+	ui->verticalScrollBar->installEventFilter(this);
 
 	ui->panel->setFocus();
-	QObject::connect(ui->panel, &PatternEditorPanel::currentCellInRowChanged,
+	QObject::connect(ui->panel, &PatternEditorPanel::hScrollBarChangeRequested,
 					 ui->horizontalScrollBar, &QScrollBar::setValue);
-	QObject::connect(ui->panel, &PatternEditorPanel::currentStepChanged,
+	QObject::connect(ui->panel, &PatternEditorPanel::vScrollBarChangeRequested,
 					 this, [&](int num, int max) {
-		ui->verticalScrollBar->setMaximum(max);
-		ui->verticalScrollBar->setValue(num);
+		if (ui->verticalScrollBar->maximum() < num) {
+			ui->verticalScrollBar->setMaximum(max);
+			ui->verticalScrollBar->setValue(num);
+		}
+		else {
+			ui->verticalScrollBar->setValue(num);
+			ui->verticalScrollBar->setMaximum(max);
+		}
 	});
 	QObject::connect(ui->panel, &PatternEditorPanel::currentTrackChanged,
 					 this, [&](int num) { emit currentTrackChanged(num); });
@@ -25,8 +35,14 @@ PatternEditor::PatternEditor(QWidget *parent) :
 
 	QObject::connect(ui->panel, &PatternEditorPanel::effectColsCompanded,
 					 this, [&](int num, int max) {
-		ui->horizontalScrollBar->setMaximum(max);
-		ui->horizontalScrollBar->setValue(num);
+		if (ui->horizontalScrollBar->maximum() < num) {
+			ui->horizontalScrollBar->setMaximum(max);
+			ui->horizontalScrollBar->setValue(num);
+		}
+		else {
+			ui->horizontalScrollBar->setValue(num);
+			ui->horizontalScrollBar->setMaximum(max);
+		}
 	});
 	QObject::connect(ui->panel, &PatternEditorPanel::selected,
 					 this, [&](bool isSelected) { emit selected(isSelected); });
@@ -40,11 +56,11 @@ PatternEditor::PatternEditor(QWidget *parent) :
 	auto focusSlot = [&] { ui->panel->setFocus(); };
 
 	QObject::connect(ui->horizontalScrollBar, &QScrollBar::valueChanged,
-					 ui->panel, &PatternEditorPanel::setCurrentCellInRow);
+					 ui->panel, &PatternEditorPanel::onHScrollBarChanged);
 	QObject::connect(ui->horizontalScrollBar, &QScrollBar::sliderPressed, this, focusSlot);
 
 	QObject::connect(ui->verticalScrollBar, &QScrollBar::valueChanged,
-					 ui->panel, &PatternEditorPanel::setCurrentStep);
+					 ui->panel, &PatternEditorPanel::onVScrollBarChanged);
 	QObject::connect(ui->verticalScrollBar, &QScrollBar::sliderPressed, this, focusSlot);
 }
 
@@ -64,12 +80,12 @@ void PatternEditor::setCommandStack(std::weak_ptr<QUndoStack> stack)
 	ui->panel->setCommandStack(stack);
 }
 
-void PatternEditor::setConfiguration(std::weak_ptr<Configuration> config)
+void PatternEditor::setConfiguration(std::shared_ptr<Configuration> config)
 {
 	ui->panel->setConfiguration(config);
 }
 
-void PatternEditor::setColorPallete(std::weak_ptr<ColorPalette> palette)
+void PatternEditor::setColorPallete(std::shared_ptr<ColorPalette> palette)
 {
 	ui->panel->setColorPallete(palette);
 }
@@ -79,9 +95,9 @@ void PatternEditor::changeEditable()
 	ui->panel->changeEditable();
 }
 
-void PatternEditor::updatePosition()
+void PatternEditor::updatePositionByStepUpdate(bool isFirstUpdate)
 {
-	ui->panel->updatePosition();
+	ui->panel->updatePositionByStepUpdate(isFirstUpdate);
 }
 
 void PatternEditor::copySelectedCells()
@@ -94,6 +110,49 @@ void PatternEditor::cutSelectedCells()
 	ui->panel->cutSelectedCells();
 }
 
+void PatternEditor::freeze()
+{
+	freezed_ = true;
+	ui->panel->freeze();
+}
+
+void PatternEditor::unfreeze()
+{
+	freezed_ = false;
+	ui->panel->unfreeze();
+}
+
+QString PatternEditor::getHeaderFont() const
+{
+	return ui->panel->getHeaderFont();
+}
+
+int PatternEditor::getHeaderFontSize() const
+{
+	return ui->panel->getHeaderFontSize();
+}
+
+QString PatternEditor::getRowsFont() const
+{
+	return ui->panel->getRowsFont();
+}
+
+int PatternEditor::getRowsFontSize() const
+{
+	return ui->panel->getRowsFontSize();
+}
+
+void PatternEditor::setFonts(QString headerFont, int headerSize, QString rowsFont, int rowsSize)
+{
+	ui->panel->setFonts(headerFont, headerSize, rowsFont, rowsSize);
+}
+
+void PatternEditor::setHorizontalScrollMode(bool cellBased, bool refresh)
+{
+	hScrollCellMove_ = cellBased;
+	if (refresh) updateHorizontalSliderMaximum();
+}
+
 bool PatternEditor::eventFilter(QObject *watched, QEvent *event)
 {
 	Q_UNUSED(watched)
@@ -106,16 +165,52 @@ bool PatternEditor::eventFilter(QObject *watched, QEvent *event)
 	}
 
 	if (watched == ui->panel) {
+		if (freezed_ && event->type() != QEvent::Paint) return true;
+
 		switch (event->type()) {
-		case QEvent::FocusIn:	emit focusIn();		return false;
-		case QEvent::FocusOut:	emit focusOut();	return false;
-		default:	return false;
+		case QEvent::FocusIn:
+			ui->panel->redrawByFocusChanged();
+			emit focusIn();
+			return false;
+		case QEvent::FocusOut:
+			ui->panel->redrawByFocusChanged();
+			emit focusOut();
+			return false;
+		case QEvent::HoverEnter:
+		case QEvent::HoverLeave:
+			ui->panel->redrawByHoverChanged();
+			return false;
+		default:
+			return false;
+		}
+	}
+
+	if (watched == ui->verticalScrollBar) {
+		if (freezed_) return true;	// Ignore every events
+
+		switch (event->type()) {
+		case QEvent::MouseButtonPress:
+		case QEvent::MouseButtonRelease:
+		case QEvent::MouseButtonDblClick:
+		case QEvent::DragMove:
+		case QEvent::Wheel:
+			return (bt_->isPlaySong() && bt_->isFollowPlay());
+		default:
+			return false;
 		}
 	}
 
 	return false;
 }
 
+void PatternEditor::resizeEvent(QResizeEvent* event)
+{
+	Q_UNUSED(event)
+
+	// For view-based scroll
+	updateHorizontalSliderMaximum();
+}
+
 /********** Slots **********/
 void PatternEditor::setCurrentTrack(int num)
 {
@@ -154,9 +249,10 @@ void PatternEditor::setEditableStep(int n)
 
 void PatternEditor::onSongLoaded()
 {
-	ui->panel->onSongLoaded();
-	ui->horizontalScrollBar->setMaximum(ui->panel->getFullColmunSize());
 	ui->horizontalScrollBar->setValue(0);
+	ui->panel->onSongLoaded();
+	songLoaded_ = true;
+	updateHorizontalSliderMaximum();
 	ui->verticalScrollBar->setMaximum(static_cast<int>(bt_->getPatternSizeFromOrderNumber(
 														   bt_->getCurrentSongNumber(),
 														   bt_->getCurrentOrderNumber())) - 1);
@@ -203,6 +299,16 @@ void PatternEditor::onSoloTrackPressed()
 	ui->panel->onSoloTrackPressed(ui->panel->getCurrentTrack());
 }
 
+void PatternEditor::onExpandEffectColumn()
+{
+	ui->panel->onExpandEffectColumnPressed(ui->panel->getCurrentTrack());
+}
+
+void PatternEditor::onShrinkEffectColumn()
+{
+	ui->panel->onShrinkEffectColumnPressed(ui->panel->getCurrentTrack());
+}
+
 void PatternEditor::onExpandPressed()
 {
 	ui->panel->onExpandPressed();
@@ -227,3 +333,25 @@ void PatternEditor::onReplaceInstrumentPressed()
 {
 	ui->panel->onReplaceInstrumentPressed();
 }
+
+void PatternEditor::onFollowModeChanged()
+{
+	ui->panel->onFollowModeChanged();
+}
+
+void PatternEditor::onStoppedPlaySong()
+{
+	ui->panel->redrawPatterns();
+}
+
+void PatternEditor::onDuplicateInstrumentsRemoved()
+{
+	ui->panel->redrawByPatternChanged();
+}
+
+void PatternEditor::updateHorizontalSliderMaximum()
+{
+	if (!ui->panel->isReadyCore() || !songLoaded_) return;
+	int max = hScrollCellMove_ ? ui->panel->getFullColmunSize() : ui->panel->getScrollableCountByTrack();
+	ui->horizontalScrollBar->setMaximum(max);
+}
