@@ -22,15 +22,26 @@ public:
 	~PatternEditor() override;
 	void setCore(std::shared_ptr<BambooTracker> core);
 	void setCommandStack(std::weak_ptr<QUndoStack> stack);
-	void setConfiguration(std::weak_ptr<Configuration> config);
-	void setColorPallete(std::weak_ptr<ColorPalette> palette);
+	void setConfiguration(std::shared_ptr<Configuration> config);
+	void setColorPallete(std::shared_ptr<ColorPalette> palette);
 
 	void changeEditable();
-	void updatePosition();
+	void updatePositionByStepUpdate(bool isFirstUpdate);
 
 	void copySelectedCells();
 	void cutSelectedCells();
 
+	void freeze();
+	void unfreeze();
+
+	QString getHeaderFont() const;
+	int getHeaderFontSize() const;
+	QString getRowsFont() const;
+	int getRowsFontSize() const;
+	void setFonts(QString headerFont, int headerSize, QString rowsFont, int rowsSize);
+
+	void setHorizontalScrollMode(bool cellBased, bool refresh = true);
+
 signals:
 	void currentTrackChanged(int num);
 	void currentOrderChanged(int num, int max);
@@ -44,6 +55,7 @@ signals:
 
 protected:
 	bool eventFilter(QObject *watched, QEvent *event) override;
+	void resizeEvent(QResizeEvent* event) override;
 
 public slots:
 	void setCurrentTrack(int num);
@@ -72,15 +84,26 @@ public slots:
 	void onTransposePressed(bool isOctave, bool isIncreased);
 	void onToggleTrackPressed();
 	void onSoloTrackPressed();
+	void onExpandEffectColumn();
+	void onShrinkEffectColumn();
 	void onExpandPressed();
 	void onShrinkPressed();
 	void onInterpolatePressed();
 	void onReversePressed();
 	void onReplaceInstrumentPressed();
+	void onFollowModeChanged();
+	void onStoppedPlaySong();
+	void onDuplicateInstrumentsRemoved();
 
 private:
 	Ui::PatternEditor *ui;
 	std::shared_ptr<BambooTracker> bt_;
+
+	bool freezed_;
+	bool songLoaded_;
+
+	bool hScrollCellMove_;
+	void updateHorizontalSliderMaximum();
 };
 
 #endif // PATTERN_EDITOR_HPP
