@@ -12,9 +12,11 @@ public:
 	int getCommandData() const override;
 	int next(bool isReleaseBegin = false) override;
 	int front() override;
+	int end() override;
 
 private:
 	int pos_;
+	bool started_;
 	int second_, third_;
 };
 
@@ -28,9 +30,11 @@ public:
 	int getCommandData() const override;
 	int next(bool isReleaseBegin = false) override;
 	int front() override;
+	int end() override;
 
 private:
 	int pos_;
+	bool started_;
 	std::vector<int> seq_;
 };
 
@@ -44,8 +48,10 @@ public:
 	int getCommandData() const override;
 	int next(bool isReleaseBegin = false) override;
 	int front() override;
+	int end() override;
 
 private:
 	int pos_;
+	bool started_;
 	std::vector<int> seq_;
 };
