@@ -2,12 +2,13 @@
 
 #include <string>
 #include <memory>
-#include <map>
+#include <unordered_map>
 #include <vector>
 #include "instruments_manager.hpp"
 #include "envelope_fm.hpp"
 #include "lfo_fm.hpp"
 #include "command_sequence.hpp"
+#include "enum_hash.hpp"
 #include "misc.hpp"
 
 class InstrumentsManager;
@@ -66,7 +67,7 @@ public:
 	bool getArpeggioEnabled(FMOperatorType op) const;
 	void setArpeggioNumber(FMOperatorType op, int n);
 	int getArpeggioNumber(FMOperatorType op) const;
-	int getArpeggioType(FMOperatorType op) const;
+	SequenceType getArpeggioType(FMOperatorType op) const;
 	std::vector<CommandSequenceUnit> getArpeggioSequence(FMOperatorType op) const;
 	std::vector<Loop> getArpeggioLoops(FMOperatorType op) const;
 	Release getArpeggioRelease(FMOperatorType op) const;
@@ -76,7 +77,7 @@ public:
 	bool getPitchEnabled(FMOperatorType op) const;
 	void setPitchNumber(FMOperatorType op, int n);
 	int getPitchNumber(FMOperatorType op) const;
-	int getPitchType(FMOperatorType op) const;
+	SequenceType getPitchType(FMOperatorType op) const;
 	std::vector<CommandSequenceUnit> getPitchSequence(FMOperatorType op) const;
 	std::vector<Loop> getPitchLoops(FMOperatorType op) const;
 	Release getPitchRelease(FMOperatorType op) const;
@@ -89,14 +90,14 @@ private:
 	int envNum_;
 	bool lfoEnabled_;
 	int lfoNum_;
-	std::map<FMEnvelopeParameter, bool> opSeqEnabled_;
-	std::map<FMEnvelopeParameter, int> opSeqNum_;
-	std::map<FMOperatorType, bool> arpEnabled_;
-	std::map<FMOperatorType, int> arpNum_;
-	std::map<FMOperatorType, bool> ptEnabled_;
-	std::map<FMOperatorType, int> ptNum_;
+	std::unordered_map<FMEnvelopeParameter, bool> opSeqEnabled_;
+	std::unordered_map<FMEnvelopeParameter, int> opSeqNum_;
+	std::unordered_map<FMOperatorType, bool> arpEnabled_;
+	std::unordered_map<FMOperatorType, int> arpNum_;
+	std::unordered_map<FMOperatorType, bool> ptEnabled_;
+	std::unordered_map<FMOperatorType, int> ptNum_;
 
-	std::map<FMOperatorType, bool> envResetEnabled_;
+	std::unordered_map<FMOperatorType, bool> envResetEnabled_;
 };
 
 
@@ -137,7 +138,7 @@ public:
 	bool getArpeggioEnabled() const;
 	void setArpeggioNumber(int n);
 	int getArpeggioNumber() const;
-	int getArpeggioType() const;
+	SequenceType getArpeggioType() const;
 	std::vector<CommandSequenceUnit> getArpeggioSequence() const;
 	std::vector<Loop> getArpeggioLoops() const;
 	Release getArpeggioRelease() const;
@@ -147,7 +148,7 @@ public:
 	bool getPitchEnabled() const;
 	void setPitchNumber(int n);
 	int getPitchNumber() const;
-	int getPitchType() const;
+	SequenceType getPitchType() const;
 	std::vector<CommandSequenceUnit> getPitchSequence() const;
 	std::vector<Loop> getPitchLoops() const;
 	Release getPitchRelease() const;
