@@ -1,6 +1,7 @@
 #include "instruments_manager.hpp"
 #include <utility>
-#include <set>
+#include <unordered_map>
+#include <algorithm>
 #include "instrument.hpp"
 
 InstrumentsManager::InstrumentsManager()
@@ -244,7 +245,7 @@ void InstrumentsManager::deepCloneInstrument(int cloneInstNum, int refInstNum)
 			}
 		}
 
-		std::map<int, int> arpNums;
+		std::unordered_map<int, int> arpNums;
 		for (auto t : fmOpTypes_) {
 			if (refFm->getArpeggioEnabled(t)) {
 				cloneFm->setArpeggioEnabled(t, true);
@@ -260,7 +261,7 @@ void InstrumentsManager::deepCloneInstrument(int cloneInstNum, int refInstNum)
 			}
 		}
 
-		std::map<int, int> ptNums;
+		std::unordered_map<int, int> ptNums;
 		for (auto t : fmOpTypes_) {
 			if (refFm->getPitchEnabled(t)) {
 				cloneFm->setPitchEnabled(t, true);
@@ -531,16 +532,16 @@ void InstrumentsManager::clearAll()
 		envFM_[i] = std::make_shared<EnvelopeFM>(i);
 		lfoFM_[i] = std::make_shared<LFOFM>(i);
 		for (auto& p : opSeqFM_) {
-			p.second[i] = std::make_shared<CommandSequence>(i, 0);
+			p.second[i] = std::make_shared<CommandSequence>(i);
 		}
-		arpFM_[i] = std::make_shared<CommandSequence>(i, 0, 48);
-		ptFM_[i] = std::make_shared<CommandSequence>(i, 0, 127);
+		arpFM_[i] = std::make_shared<CommandSequence>(i, SequenceType::ABSOLUTE_SEQUENCE, 48);
+		ptFM_[i] = std::make_shared<CommandSequence>(i, SequenceType::ABSOLUTE_SEQUENCE, 127);
 
-		wfSSG_[i] = std::make_shared<CommandSequence>(i, 0);
-		tnSSG_[i] = std::make_shared<CommandSequence>(i, 0);
-		envSSG_[i] = std::make_shared<CommandSequence>(i, 0, 15);
-		arpSSG_[i] = std::make_shared<CommandSequence>(i, 0, 48);
-		ptSSG_[i] = std::make_shared<CommandSequence>(i, 0, 127);
+		wfSSG_[i] = std::make_shared<CommandSequence>(i);
+		tnSSG_[i] = std::make_shared<CommandSequence>(i);
+		envSSG_[i] = std::make_shared<CommandSequence>(i,SequenceType::NO_SEQUENCE_TYPE, 15);
+		arpSSG_[i] = std::make_shared<CommandSequence>(i, SequenceType::ABSOLUTE_SEQUENCE, 48);
+		ptSSG_[i] = std::make_shared<CommandSequence>(i, SequenceType::ABSOLUTE_SEQUENCE, 127);
 	}
 }
 
@@ -592,23 +593,23 @@ void InstrumentsManager::clearUnusedInstrumentProperties()
 			lfoFM_[i] = std::make_shared<LFOFM>(i);
 		for (auto& p : opSeqFM_) {
 			if (!p.second[i]->isUserInstrument())
-				p.second[i] = std::make_shared<CommandSequence>(i, 0);
+				p.second[i] = std::make_shared<CommandSequence>(i);
 		}
 		if (!arpFM_[i]->isUserInstrument())
-			arpFM_[i] = std::make_shared<CommandSequence>(i, 0, 48);
+			arpFM_[i] = std::make_shared<CommandSequence>(i, SequenceType::ABSOLUTE_SEQUENCE, 48);
 		if (!ptFM_[i]->isUserInstrument())
-			ptFM_[i] = std::make_shared<CommandSequence>(i, 0, 127);
+			ptFM_[i] = std::make_shared<CommandSequence>(i, SequenceType::ABSOLUTE_SEQUENCE, 127);
 
 		if (!wfSSG_[i]->isUserInstrument())
-			wfSSG_[i] = std::make_shared<CommandSequence>(i, 0);
+			wfSSG_[i] = std::make_shared<CommandSequence>(i);
 		if (!tnSSG_[i]->isUserInstrument())
-			tnSSG_[i] = std::make_shared<CommandSequence>(i, 0);
+			tnSSG_[i] = std::make_shared<CommandSequence>(i);
 		if (!envSSG_[i]->isUserInstrument())
-			envSSG_[i] = std::make_shared<CommandSequence>(i, 0, 15);
+			envSSG_[i] = std::make_shared<CommandSequence>(i, SequenceType::NO_SEQUENCE_TYPE, 15);
 		if (!arpSSG_[i]->isUserInstrument())
-			arpSSG_[i] = std::make_shared<CommandSequence>(i, 0, 48);
+			arpSSG_[i] = std::make_shared<CommandSequence>(i, SequenceType::ABSOLUTE_SEQUENCE, 48);
 		if (!ptSSG_[i]->isUserInstrument())
-			ptSSG_[i] = std::make_shared<CommandSequence>(i, 0, 127);
+			ptSSG_[i] = std::make_shared<CommandSequence>(i, SequenceType::ABSOLUTE_SEQUENCE, 127);
 	}
 }
 
@@ -617,12 +618,57 @@ void InstrumentsManager::clearUnusedInstrumentProperties()
 ///		else: first free instrument number
 int InstrumentsManager::findFirstFreeInstrument() const
 {
-	int num = 0;
-	for (auto& inst : insts_) {
-		if (!inst) return num;
-		++num;
+	auto&& it = std::find_if_not(insts_.begin(), insts_.end(),
+								 [](const std::shared_ptr<AbstractInstrument>& inst) { return inst; });
+	return (it == insts_.end() ? -1 : std::distance(insts_.begin(), it));
+}
+
+std::vector<std::vector<int>> InstrumentsManager::checkDuplicateInstruments() const
+{
+	std::vector<std::vector<int>> dupList;
+	std::vector<int> idcs = getEntriedInstrumentIndices();
+	for (size_t i = 0; i < idcs.size(); ++i) {
+		int baseIdx = idcs[i];
+		std::vector<int> group { baseIdx };
+		std::shared_ptr<AbstractInstrument> base = insts_[baseIdx];
+
+		for (size_t j = i + 1; j < idcs.size();) {
+			int tgtIdx = idcs[j];
+			std::shared_ptr<AbstractInstrument> tgt = insts_[tgtIdx];
+
+			if (base->getSoundSource() == tgt->getSoundSource()) {
+				switch (base->getSoundSource()) {
+				case SoundSource::FM:
+				{
+					if (equalPropertiesFM(std::dynamic_pointer_cast<InstrumentFM>(base),
+										  std::dynamic_pointer_cast<InstrumentFM>(tgt))) {
+						group.push_back(tgtIdx);
+						idcs.erase(idcs.begin() + j);
+						continue;
+					}
+					break;
+				}
+				case SoundSource::SSG:
+				{
+					if (equalPropertiesSSG(std::dynamic_pointer_cast<InstrumentSSG>(base),
+										  std::dynamic_pointer_cast<InstrumentSSG>(tgt))) {
+						group.push_back(tgtIdx);
+						idcs.erase(idcs.begin() + j);
+						continue;
+					}
+					break;
+				}
+				case SoundSource::DRUM:
+					break;
+				}
+			}
+			++j;
+		}
+
+		if (group.size() > 1) dupList.push_back(group);
 	}
-	return -1;
+
+	return dupList;
 }
 
 //----- FM methods -----
@@ -678,18 +724,16 @@ std::vector<int> InstrumentsManager::getEnvelopeFMEntriedIndices() const
 
 int InstrumentsManager::findFirstFreeEnvelopeFM() const
 {
-	for (size_t i = 0; i < envFM_.size(); ++i) {
-		if (!envFM_[i]->isUserInstrument()) return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(envFM_.begin(), envFM_.end(),
+								 [](const std::shared_ptr<EnvelopeFM>& env) { return env->isUserInstrument(); });
+	return (it == envFM_.end() ? -1 : std::distance(envFM_.begin(), it));
 }
 
 int InstrumentsManager::findFirstFreePlainEnvelopeFM() const
 {
-	for (size_t i = 0; i < envFM_.size(); ++i) {
-		if (!envFM_[i]->isUserInstrument() && !envFM_[i]->isEdited()) return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(envFM_.begin(), envFM_.end(),
+								 [](const std::shared_ptr<EnvelopeFM>& env) { return (env->isUserInstrument() || env->isEdited()); });
+	return (it == envFM_.end() ? -1 : std::distance(envFM_.begin(), it));
 }
 
 void InstrumentsManager::setInstrumentFMLFOEnabled(int instNum, bool enabled)
@@ -747,18 +791,16 @@ std::vector<int> InstrumentsManager::getLFOFMEntriedIndices() const
 
 int InstrumentsManager::findFirstFreeLFOFM() const
 {
-	for (size_t i = 0; i < lfoFM_.size(); ++i) {
-		if (!lfoFM_[i]->isUserInstrument()) return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(lfoFM_.begin(), lfoFM_.end(),
+								 [](const std::shared_ptr<LFOFM>& lfo) { return lfo->isUserInstrument(); });
+	return (it == lfoFM_.end() ? -1 : std::distance(lfoFM_.begin(), it));
 }
 
 int InstrumentsManager::findFirstFreePlainLFOFM() const
 {
-	for (size_t i = 0; i < lfoFM_.size(); ++i) {
-		if (!lfoFM_[i]->isUserInstrument() && !lfoFM_[i]->isEdited()) return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(lfoFM_.begin(), lfoFM_.end(),
+								 [](const std::shared_ptr<LFOFM>& lfo) { return (lfo->isUserInstrument() || lfo->isEdited()); });
+	return (it == lfoFM_.end() ? -1 : std::distance(lfoFM_.begin(), it));
 }
 
 void InstrumentsManager::setInstrumentFMOperatorSequenceEnabled(int instNum, FMEnvelopeParameter param, bool enabled)
@@ -854,19 +896,18 @@ std::vector<int> InstrumentsManager::getOperatorSequenceFMEntriedIndices(FMEnvel
 
 int InstrumentsManager::findFirstFreeOperatorSequenceFM(FMEnvelopeParameter param) const
 {
-	for (size_t i = 0; i < opSeqFM_.at(param).size(); ++i) {
-		if (!opSeqFM_.at(param)[i]->isUserInstrument()) return static_cast<int>(i);
-	}
-	return -1;
+	auto& opSeq = opSeqFM_.at(param);
+	auto&& it = std::find_if_not(opSeq.begin(), opSeq.end(),
+								 [](const std::shared_ptr<CommandSequence>& seq) { return seq->isUserInstrument(); });
+	return (it == opSeq.end() ? -1 : std::distance(opSeq.begin(), it));
 }
 
 int InstrumentsManager::findFirstFreePlainOperatorSequenceFM(FMEnvelopeParameter param) const
 {
-	for (size_t i = 0; i < opSeqFM_.at(param).size(); ++i) {
-		if (!opSeqFM_.at(param)[i]->isUserInstrument() && !opSeqFM_.at(param)[i]->isEdited())
-			return static_cast<int>(i);
-	}
-	return -1;
+	auto& opSeq = opSeqFM_.at(param);
+	auto&& it = std::find_if_not(opSeq.begin(), opSeq.end(),
+								 [](const std::shared_ptr<CommandSequence>& seq) { return (seq->isUserInstrument() || seq->isEdited()); });
+	return (it == opSeq.end() ? -1 : std::distance(opSeq.begin(), it));
 }
 
 void InstrumentsManager::setInstrumentFMArpeggioEnabled(int instNum, FMOperatorType op, bool enabled)
@@ -899,12 +940,12 @@ int InstrumentsManager::getInstrumentFMArpeggio(int instNum, FMOperatorType op)
 	return std::dynamic_pointer_cast<InstrumentFM>(insts_[static_cast<size_t>(instNum)])->getArpeggioNumber(op);
 }
 
-void InstrumentsManager::setArpeggioFMType(int arpNum, int type)
+void InstrumentsManager::setArpeggioFMType(int arpNum, SequenceType type)
 {
 	arpFM_.at(static_cast<size_t>(arpNum))->setType(type);
 }
 
-int InstrumentsManager::getArpeggioFMType(int arpNum) const
+SequenceType InstrumentsManager::getArpeggioFMType(int arpNum) const
 {
 	return arpFM_.at(static_cast<size_t>(arpNum))->getType();
 }
@@ -972,19 +1013,16 @@ std::vector<int> InstrumentsManager::getArpeggioFMEntriedIndices() const
 
 int InstrumentsManager::findFirstFreeArpeggioFM() const
 {
-	for (size_t i = 0; i < arpFM_.size(); ++i) {
-		if (!arpFM_[i]->isUserInstrument()) return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(arpFM_.begin(), arpFM_.end(),
+								 [](const std::shared_ptr<CommandSequence>& arp) { return arp->isUserInstrument(); });
+	return (it == arpFM_.end() ? -1 : std::distance(arpFM_.begin(), it));
 }
 
 int InstrumentsManager::findFirstFreePlainArpeggioFM() const
 {
-	for (size_t i = 0; i < arpFM_.size(); ++i) {
-		if (!arpFM_[i]->isUserInstrument() && !arpFM_[i]->isEdited())
-			return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(arpFM_.begin(), arpFM_.end(),
+								 [](const std::shared_ptr<CommandSequence>& arp) { return (arp->isUserInstrument() || arp->isEdited()); });
+	return (it == arpFM_.end() ? -1 : std::distance(arpFM_.begin(), it));
 }
 
 void InstrumentsManager::setInstrumentFMPitchEnabled(int instNum, FMOperatorType op, bool enabled)
@@ -1017,12 +1055,12 @@ int InstrumentsManager::getInstrumentFMPitch(int instNum, FMOperatorType op)
 	return std::dynamic_pointer_cast<InstrumentFM>(insts_[static_cast<size_t>(instNum)])->getPitchNumber(op);
 }
 
-void InstrumentsManager::setPitchFMType(int ptNum, int type)
+void InstrumentsManager::setPitchFMType(int ptNum, SequenceType type)
 {
 	ptFM_.at(static_cast<size_t>(ptNum))->setType(type);
 }
 
-int InstrumentsManager::getPitchFMType(int ptNum) const
+SequenceType InstrumentsManager::getPitchFMType(int ptNum) const
 {
 	return ptFM_.at(static_cast<size_t>(ptNum))->getType();
 }
@@ -1095,19 +1133,48 @@ std::vector<int> InstrumentsManager::getPitchFMEntriedIndices() const
 
 int InstrumentsManager::findFirstFreePitchFM() const
 {
-	for (size_t i = 0; i < ptFM_.size(); ++i) {
-		if (!ptFM_[i]->isUserInstrument()) return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(ptFM_.begin(), ptFM_.end(),
+								 [](const std::shared_ptr<CommandSequence>& pt) { return pt->isUserInstrument(); });
+	return (it == ptFM_.end() ? -1 : std::distance(ptFM_.begin(), it));
 }
 
 int InstrumentsManager::findFirstFreePlainPitchFM() const
 {
-	for (size_t i = 0; i < ptFM_.size(); ++i) {
-		if (!ptFM_[i]->isUserInstrument() && !ptFM_[i]->isEdited())
-			return static_cast<int>(i);
+	auto&& it = std::find_if_not(ptFM_.begin(), ptFM_.end(),
+								 [](const std::shared_ptr<CommandSequence>& pt) { return (pt->isUserInstrument() || pt->isEdited()); });
+	return (it == ptFM_.end() ? -1 : std::distance(ptFM_.begin(), it));
+}
+
+bool InstrumentsManager::equalPropertiesFM(std::shared_ptr<InstrumentFM> a, std::shared_ptr<InstrumentFM> b) const
+{
+	if (*envFM_[a->getEnvelopeNumber()].get() != *envFM_[b->getEnvelopeNumber()].get())
+		return false;
+	if (a->getLFOEnabled() != b->getLFOEnabled())
+		return false;
+	if (a->getLFOEnabled() && *lfoFM_[a->getLFONumber()].get() != *lfoFM_[b->getLFONumber()].get())
+		return false;
+	for (auto& pair : opSeqFM_) {
+		if (a->getOperatorSequenceEnabled(pair.first) != b->getOperatorSequenceEnabled(pair.first))
+			return false;
+		if (a->getOperatorSequenceEnabled(pair.first)
+				&& *pair.second[a->getOperatorSequenceNumber(pair.first)].get() != *pair.second[b->getOperatorSequenceNumber(pair.first)].get())
+			return false;
 	}
-	return -1;
+	for (auto& type : fmOpTypes_) {
+		if (a->getArpeggioEnabled(type) != b->getArpeggioEnabled(type))
+			return false;
+		if (a->getArpeggioEnabled(type)
+				&& *arpFM_[a->getArpeggioNumber(type)].get() != *arpFM_[b->getArpeggioNumber(type)].get())
+			return false;
+		if (a->getPitchEnabled(type) != b->getPitchEnabled(type))
+			return false;
+		if (a->getPitchEnabled(type)
+				&& *ptFM_[a->getPitchNumber(type)].get() != *ptFM_[b->getPitchNumber(type)].get())
+			return false;
+		if (a->getEnvelopeResetEnabled(type) != b->getEnvelopeResetEnabled(type))
+			return false;
+	}
+	return true;
 }
 
 //----- SSG methods -----
@@ -1204,19 +1271,16 @@ std::vector<int> InstrumentsManager::getWaveFormSSGEntriedIndices() const
 
 int InstrumentsManager::findFirstFreeWaveFormSSG() const
 {
-	for (size_t i = 0; i < wfSSG_.size(); ++i) {
-		if (!wfSSG_[i]->isUserInstrument()) return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(wfSSG_.begin(), wfSSG_.end(),
+								 [](const std::shared_ptr<CommandSequence>& wf) { return wf->isUserInstrument(); });
+	return (it == wfSSG_.end() ? -1 : std::distance(wfSSG_.begin(), it));
 }
 
 int InstrumentsManager::findFirstFreePlainWaveFormSSG() const
 {
-	for (size_t i = 0; i < wfSSG_.size(); ++i) {
-		if (!wfSSG_[i]->isUserInstrument() && !wfSSG_[i]->isEdited())
-			return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(wfSSG_.begin(), wfSSG_.end(),
+								 [](const std::shared_ptr<CommandSequence>& wf) { return (wf->isUserInstrument() || wf->isEdited()); });
+	return (it == wfSSG_.end() ? -1 : std::distance(wfSSG_.begin(), it));
 }
 
 void InstrumentsManager::setInstrumentSSGToneNoiseEnabled(int instNum, bool enabled)
@@ -1312,19 +1376,16 @@ std::vector<int> InstrumentsManager::getToneNoiseSSGEntriedIndices() const
 
 int InstrumentsManager::findFirstFreeToneNoiseSSG() const
 {
-	for (size_t i = 0; i < tnSSG_.size(); ++i) {
-		if (!tnSSG_[i]->isUserInstrument()) return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(tnSSG_.begin(), tnSSG_.end(),
+								 [](const std::shared_ptr<CommandSequence>& tn) { return tn->isUserInstrument(); });
+	return (it == tnSSG_.end() ? -1 : std::distance(tnSSG_.begin(), it));
 }
 
 int InstrumentsManager::findFirstFreePlainToneNoiseSSG() const
 {
-	for (size_t i = 0; i < tnSSG_.size(); ++i) {
-		if (!tnSSG_[i]->isUserInstrument() && !tnSSG_[i]->isEdited())
-			return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(tnSSG_.begin(), tnSSG_.end(),
+								 [](const std::shared_ptr<CommandSequence>& tn) { return (tn->isUserInstrument() || tn->isEdited()); });
+	return (it == tnSSG_.end() ? -1 : std::distance(tnSSG_.begin(), it));
 }
 
 void InstrumentsManager::setInstrumentSSGEnvelopeEnabled(int instNum, bool enabled)
@@ -1420,19 +1481,16 @@ std::vector<int> InstrumentsManager::getEnvelopeSSGEntriedIndices() const
 
 int InstrumentsManager::findFirstFreeEnvelopeSSG() const
 {
-	for (size_t i = 0; i < envSSG_.size(); ++i) {
-		if (!envSSG_[i]->isUserInstrument()) return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(envSSG_.begin(), envSSG_.end(),
+								 [](const std::shared_ptr<CommandSequence>& env) { return env->isUserInstrument(); });
+	return (it == envSSG_.end() ? -1 : std::distance(envSSG_.begin(), it));
 }
 
 int InstrumentsManager::findFirstFreePlainEnvelopeSSG() const
 {
-	for (size_t i = 0; i < envSSG_.size(); ++i) {
-		if (!envSSG_[i]->isUserInstrument() && !envSSG_[i]->isEdited())
-			return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(envSSG_.begin(), envSSG_.end(),
+								 [](const std::shared_ptr<CommandSequence>& env) { return (env->isUserInstrument() || env->isEdited()); });
+	return (it == envSSG_.end() ? -1 : std::distance(envSSG_.begin(), it));
 }
 
 void InstrumentsManager::setInstrumentSSGArpeggioEnabled(int instNum, bool enabled)
@@ -1465,12 +1523,12 @@ int InstrumentsManager::getInstrumentSSGArpeggio(int instNum)
 	return std::dynamic_pointer_cast<InstrumentSSG>(insts_[static_cast<size_t>(instNum)])->getArpeggioNumber();
 }
 
-void InstrumentsManager::setArpeggioSSGType(int arpNum, int type)
+void InstrumentsManager::setArpeggioSSGType(int arpNum, SequenceType type)
 {
 	arpSSG_.at(static_cast<size_t>(arpNum))->setType(type);
 }
 
-int InstrumentsManager::getArpeggioSSGType(int arpNum) const
+SequenceType InstrumentsManager::getArpeggioSSGType(int arpNum) const
 {
 	return arpSSG_.at(static_cast<size_t>(arpNum))->getType();
 }
@@ -1538,19 +1596,16 @@ std::vector<int> InstrumentsManager::getArpeggioSSGEntriedIndices() const
 
 int InstrumentsManager::findFirstFreeArpeggioSSG() const
 {
-	for (size_t i = 0; i < arpSSG_.size(); ++i) {
-		if (!arpSSG_[i]->isUserInstrument()) return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(arpSSG_.begin(), arpSSG_.end(),
+								 [](const std::shared_ptr<CommandSequence>& arp) { return arp->isUserInstrument(); });
+	return (it == arpSSG_.end() ? -1 : std::distance(arpSSG_.begin(), it));
 }
 
 int InstrumentsManager::findFirstFreePlainArpeggioSSG() const
 {
-	for (size_t i = 0; i < arpSSG_.size(); ++i) {
-		if (!arpSSG_[i]->isUserInstrument() && !arpSSG_[i]->isEdited())
-			return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(arpSSG_.begin(), arpSSG_.end(),
+								 [](const std::shared_ptr<CommandSequence>& arp) { return (arp->isUserInstrument() || arp->isEdited()); });
+	return (it == arpSSG_.end() ? -1 : std::distance(arpSSG_.begin(), it));
 }
 
 void InstrumentsManager::setInstrumentSSGPitchEnabled(int instNum, bool enabled)
@@ -1583,12 +1638,12 @@ int InstrumentsManager::getInstrumentSSGPitch(int instNum)
 	return std::dynamic_pointer_cast<InstrumentSSG>(insts_[static_cast<size_t>(instNum)])->getPitchNumber();
 }
 
-void InstrumentsManager::setPitchSSGType(int ptNum, int type)
+void InstrumentsManager::setPitchSSGType(int ptNum, SequenceType type)
 {
 	ptSSG_.at(static_cast<size_t>(ptNum))->setType(type);
 }
 
-int InstrumentsManager::getPitchSSGType(int ptNum) const
+SequenceType InstrumentsManager::getPitchSSGType(int ptNum) const
 {
 	return ptSSG_.at(static_cast<size_t>(ptNum))->getType();
 }
@@ -1656,17 +1711,44 @@ std::vector<int> InstrumentsManager::getPitchSSGEntriedIndices() const
 
 int InstrumentsManager::findFirstFreePitchSSG() const
 {
-	for (size_t i = 0; i < ptSSG_.size(); ++i) {
-		if (!ptSSG_[i]->isUserInstrument()) return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(ptSSG_.begin(), ptSSG_.end(),
+								 [](const std::shared_ptr<CommandSequence>& pt) { return pt->isUserInstrument(); });
+	return (it == ptSSG_.end() ? -1 : std::distance(ptSSG_.begin(), it));
 }
 
 int InstrumentsManager::findFirstFreePlainPitchSSG() const
 {
-	for (size_t i = 0; i < ptSSG_.size(); ++i) {
-		if (!ptSSG_[i]->isUserInstrument() && !ptSSG_[i]->isEdited())
-			return static_cast<int>(i);
-	}
-	return -1;
+	auto&& it = std::find_if_not(ptSSG_.begin(), ptSSG_.end(),
+								 [](const std::shared_ptr<CommandSequence>& pt) { return (pt->isUserInstrument() || pt->isEdited()); });
+	return (it == ptSSG_.end() ? -1 : std::distance(ptSSG_.begin(), it));
+}
+
+bool InstrumentsManager::equalPropertiesSSG(std::shared_ptr<InstrumentSSG> a, std::shared_ptr<InstrumentSSG> b) const
+{
+	if (a->getWaveFormEnabled() != b->getWaveFormEnabled())
+		return false;
+	if (a->getWaveFormEnabled()
+			&& *wfSSG_[a->getWaveFormNumber()].get() != *wfSSG_[b->getWaveFormNumber()].get())
+		return false;
+	if (a->getToneNoiseEnabled() != b->getToneNoiseEnabled())
+		return false;
+	if (a->getToneNoiseEnabled()
+			&& *tnSSG_[a->getToneNoiseNumber()].get() != *tnSSG_[b->getToneNoiseNumber()].get())
+		return false;
+	if (a->getEnvelopeEnabled() != b->getEnvelopeEnabled())
+		return false;
+	if (a->getEnvelopeEnabled()
+			&& *envSSG_[a->getEnvelopeNumber()].get() != *envSSG_[b->getEnvelopeNumber()].get())
+		return false;
+	if (a->getArpeggioEnabled() != b->getArpeggioEnabled())
+		return false;
+	if (a->getArpeggioEnabled()
+			&& *arpSSG_[a->getArpeggioNumber()].get() != *arpSSG_[b->getArpeggioNumber()].get())
+		return false;
+	if (a->getPitchEnabled() != b->getPitchEnabled())
+		return false;
+	if (a->getPitchEnabled()
+			&& *ptSSG_[a->getPitchNumber()].get() != *ptSSG_[b->getPitchNumber()].get())
+		return false;
+	return true;
 }
