@@ -4,16 +4,19 @@
 #include <memory>
 #include <array>
 #include <vector>
-#include <map>
+#include <unordered_map>
 #include "instrument.hpp"
 #include "envelope_fm.hpp"
 #include "lfo_fm.hpp"
 #include "command_sequence.hpp"
+#include "enum_hash.hpp"
 #include "misc.hpp"
 
 class AbstractInstrument;
+class InstrumentFM;
 enum class FMEnvelopeParameter;
 class EnvelopeFM;
+class InstrumentSSG;
 
 class InstrumentsManager
 {
@@ -39,6 +42,8 @@ public:
 
 	int findFirstFreeInstrument() const;
 
+	std::vector<std::vector<int>> checkDuplicateInstruments() const;
+
 private:
 	std::array<std::shared_ptr<AbstractInstrument>, 128> insts_;
 
@@ -88,8 +93,8 @@ public:
 	bool getInstrumentFMArpeggioEnabled(int instNum, FMOperatorType op) const;
 	void setInstrumentFMArpeggio(int instNum, FMOperatorType op, int arpNum);
 	int getInstrumentFMArpeggio(int instNum, FMOperatorType op);
-	void setArpeggioFMType(int arpNum, int type);
-	int getArpeggioFMType(int arpNum) const;
+	void setArpeggioFMType(int arpNum, SequenceType type);
+	SequenceType getArpeggioFMType(int arpNum) const;
 	void addArpeggioFMSequenceCommand(int arpNum, int type, int data);
 	void removeArpeggioFMSequenceCommand(int arpNum);
 	void setArpeggioFMSequenceCommand(int arpNum, int cnt, int type, int data);
@@ -108,8 +113,8 @@ public:
 	bool getInstrumentFMPitchEnabled(int instNum, FMOperatorType op) const;
 	void setInstrumentFMPitch(int instNum, FMOperatorType op, int ptNum);
 	int getInstrumentFMPitch(int instNum, FMOperatorType op);
-	void setPitchFMType(int ptNum, int type);
-	int getPitchFMType(int ptNum) const;
+	void setPitchFMType(int ptNum, SequenceType type);
+	SequenceType getPitchFMType(int ptNum) const;
 	void addPitchFMSequenceCommand(int ptNum, int type, int data);
 	void removePitchFMSequenceCommand(int ptNum);
 	void setPitchFMSequenceCommand(int ptNum, int cnt, int type, int data);
@@ -129,7 +134,7 @@ public:
 private:
 	std::array<std::shared_ptr<EnvelopeFM>, 128> envFM_;
 	std::array<std::shared_ptr<LFOFM>, 128> lfoFM_;
-	std::map<FMEnvelopeParameter, std::array<std::shared_ptr<CommandSequence>, 128>> opSeqFM_;
+	std::unordered_map<FMEnvelopeParameter, std::array<std::shared_ptr<CommandSequence>, 128>> opSeqFM_;
 	std::array<std::shared_ptr<CommandSequence>, 128> arpFM_;
 	std::array<std::shared_ptr<CommandSequence>, 128> ptFM_;
 
@@ -142,6 +147,8 @@ private:
 	int cloneFMArpeggio(int srcNum);
 	int cloneFMPitch(int srcNum);
 
+	bool equalPropertiesFM(std::shared_ptr<InstrumentFM> a, std::shared_ptr<InstrumentFM> b) const;
+
 	//----- SSG methods -----
 public:
 	void setInstrumentSSGWaveFormEnabled(int instNum, bool enabled);
@@ -202,8 +209,8 @@ public:
 	bool getInstrumentSSGArpeggioEnabled(int instNum) const;
 	void setInstrumentSSGArpeggio(int instNum, int arpNum);
 	int getInstrumentSSGArpeggio(int instNum);
-	void setArpeggioSSGType(int arpNum, int type);
-	int getArpeggioSSGType(int arpNum) const;
+	void setArpeggioSSGType(int arpNum, SequenceType type);
+	SequenceType getArpeggioSSGType(int arpNum) const;
 	void addArpeggioSSGSequenceCommand(int arpNum, int type, int data);
 	void removeArpeggioSSGSequenceCommand(int arpNum);
 	void setArpeggioSSGSequenceCommand(int arpNum, int cnt, int type, int data);
@@ -222,8 +229,8 @@ public:
 	bool getInstrumentSSGPitchEnabled(int instNum) const;
 	void setInstrumentSSGPitch(int instNum, int ptNum);
 	int getInstrumentSSGPitch(int instNum);
-	void setPitchSSGType(int ptNum, int type);
-	int getPitchSSGType(int ptNum) const;
+	void setPitchSSGType(int ptNum, SequenceType type);
+	SequenceType getPitchSSGType(int ptNum) const;
 	void addPitchSSGSequenceCommand(int ptNum, int type, int data);
 	void removePitchSSGSequenceCommand(int ptNum);
 	void setPitchSSGSequenceCommand(int ptNum, int cnt, int type, int data);
@@ -250,4 +257,6 @@ private:
 	int cloneSSGEnvelope(int srcNum);
 	int cloneSSGArpeggio(int srcNum);
 	int cloneSSGPitch(int srcNum);
+
+	bool equalPropertiesSSG(std::shared_ptr<InstrumentSSG> a, std::shared_ptr<InstrumentSSG> b) const;
 };
