@@ -25,6 +25,13 @@ LFOFM::LFOFM(const LFOFM& other)
 		amOp_[i] = other.amOp_[i];
 }
 
+bool operator==(const LFOFM& a, const LFOFM& b)
+{
+	return (a.freq_ == b.freq_ && a.ams_ == b.ams_ && a.pms_ == b.pms_ && a.cnt_ == b.cnt_
+			&& a.amOp_[0] == b.amOp_[0] && a.amOp_[1] == b.amOp_[1]
+			&& a.amOp_[2] == b.amOp_[2] && a.amOp_[3] == b.amOp_[3]);
+}
+
 std::unique_ptr<LFOFM> LFOFM::clone()
 {
 	std::unique_ptr<LFOFM> clone = std::make_unique<LFOFM>(*this);
@@ -38,7 +45,7 @@ void LFOFM::setParameterValue(FMLFOParameter param, int value)
 	case FMLFOParameter::FREQ:	freq_ = value;		break;
 	case FMLFOParameter::PMS:	pms_ = value;		break;
 	case FMLFOParameter::AMS:	ams_ = value;		break;
-	case FMLFOParameter::COUNT:	cnt_ = value;		break;
+	case FMLFOParameter::Count:	cnt_ = value;		break;
 	case FMLFOParameter::AM1:	amOp_[0] = value;	break;
 	case FMLFOParameter::AM2:	amOp_[1] = value;	break;
 	case FMLFOParameter::AM3:	amOp_[2] = value;	break;
@@ -52,7 +59,7 @@ int LFOFM::getParameterValue(FMLFOParameter param) const
 	case FMLFOParameter::FREQ:	return freq_;
 	case FMLFOParameter::PMS:	return pms_;
 	case FMLFOParameter::AMS:	return ams_;
-	case FMLFOParameter::COUNT:	return cnt_;
+	case FMLFOParameter::Count:	return cnt_;
 	case FMLFOParameter::AM1:	return amOp_[0];
 	case FMLFOParameter::AM2:	return amOp_[1];
 	case FMLFOParameter::AM3:	return amOp_[2];
