@@ -1,21 +1,15 @@
 #include "bank_io.hpp"
 #include <algorithm>
 #include <iterator>
-#include <nowide/fstream.hpp>
 #include "file_io.hpp"
 #include "file_io_error.hpp"
-#include "binary_container.hpp"
 #include "version.hpp"
 
-BankIO::BankIO()
-{
-}
+BankIO::BankIO() {}
 
-void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
+void BankIO::saveBank(BinaryContainer& ctr, std::vector<int> instNums,
 					  std::weak_ptr<InstrumentsManager> instMan)
 {
-	BinaryContainer ctr;
-
 	ctr.appendString("BambooTrackerBnk");
 	size_t eofOfs = ctr.size();
 	ctr.appendUint32(0);	// Dummy EOF offset
@@ -84,7 +78,7 @@ void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
 				ctr.appendUint8(instSSG->getPitchEnabled() ? tmp : (0x80 | tmp));
 				break;
 			}
-			case SoundSource::Drum:
+			case SoundSource::DRUM:
 				break;
 			}
 			ctr.writeUint32(iOfs, ctr.size() - iOfs);
@@ -220,7 +214,7 @@ void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
 				  | static_cast<uint8_t>(instMan.lock()->getLFOFMparameter(idx, FMLFOParameter::AM1) << 4)
 				  | static_cast<uint8_t>(instMan.lock()->getLFOFMparameter(idx, FMLFOParameter::AMS));
 			ctr.appendUint8(tmp);
-			tmp = static_cast<uint8_t>(instMan.lock()->getLFOFMparameter(idx, FMLFOParameter::COUNT));
+			tmp = static_cast<uint8_t>(instMan.lock()->getLFOFMparameter(idx, FMLFOParameter::Count));
 			ctr.appendUint8(tmp);
 			ctr.writeUint8(ofs, static_cast<uint8_t>(ctr.size() - ofs));
 		}
@@ -256,18 +250,18 @@ void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
 				}
 				auto release = instMan.lock()->getOperatorSequenceFMRelease(FileIO::ENV_FM_PARAMS[i], idx);
 				switch (release.type) {
-				case ReleaseType::NO_RELEASE:
+				case ReleaseType::NoRelease:
 					ctr.appendUint8(0x00);
 					break;
-				case ReleaseType::FIX:
+				case ReleaseType::FixedRelease:
 					ctr.appendUint8(0x01);
 					ctr.appendUint16(static_cast<uint16_t>(release.begin));
 					break;
-				case ReleaseType::ABSOLUTE:
+				case ReleaseType::AbsoluteRelease:
 					ctr.appendUint8(0x02);
 					ctr.appendUint16(static_cast<uint16_t>(release.begin));
 					break;
-				case ReleaseType::RELATIVE:
+				case ReleaseType::RelativeRelease:
 					ctr.appendUint8(0x03);
 					ctr.appendUint16(static_cast<uint16_t>(release.begin));
 					break;
@@ -307,24 +301,29 @@ void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
 			}
 			auto release = instMan.lock()->getArpeggioFMRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
 			}
-			ctr.appendUint8(static_cast<uint8_t>(instMan.lock()->getArpeggioFMType(idx)));
+			switch (instMan.lock()->getArpeggioFMType(idx)) {
+			case SequenceType::ABSOLUTE_SEQUENCE:	ctr.appendUint8(0x00);	break;
+			case SequenceType::FIXED_SEQUENCE:		ctr.appendUint8(0x01);	break;
+			case SequenceType::RELATIVE_SEQUENCE:	ctr.appendUint8(0x02);	break;
+			default:												break;
+			}
 			ctr.writeUint16(ofs, static_cast<uint16_t>(ctr.size() - ofs));
 		}
 	}
@@ -358,24 +357,28 @@ void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
 			}
 			auto release = instMan.lock()->getPitchFMRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
 			}
-			ctr.appendUint8(static_cast<uint8_t>(instMan.lock()->getPitchFMType(idx)));
+			switch (instMan.lock()->getPitchFMType(idx)) {
+			case SequenceType::ABSOLUTE_SEQUENCE:	ctr.appendUint8(0x00);	break;
+			case SequenceType::RELATIVE_SEQUENCE:	ctr.appendUint8(0x02);	break;
+			default:												break;
+			}
 			ctr.writeUint16(ofs, static_cast<uint16_t>(ctr.size() - ofs));
 		}
 	}
@@ -410,19 +413,19 @@ void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
 			}
 			auto release = instMan.lock()->getWaveFormSSGRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
@@ -461,19 +464,19 @@ void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
 			}
 			auto release = instMan.lock()->getToneNoiseSSGRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
@@ -514,19 +517,19 @@ void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
 			auto release = instMan.lock()->getEnvelopeSSGRelease(idx);
 
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
@@ -565,24 +568,29 @@ void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
 			}
 			auto release = instMan.lock()->getArpeggioSSGRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
 			}
-			ctr.appendUint8(static_cast<uint8_t>(instMan.lock()->getArpeggioSSGType(idx)));
+			switch (instMan.lock()->getArpeggioSSGType(idx)) {
+			case SequenceType::ABSOLUTE_SEQUENCE:	ctr.appendUint8(0x00);	break;
+			case SequenceType::FIXED_SEQUENCE:		ctr.appendUint8(0x01);	break;
+			case SequenceType::RELATIVE_SEQUENCE:	ctr.appendUint8(0x02);	break;
+			default:												break;
+			}
 			ctr.writeUint16(ofs, static_cast<uint16_t>(ctr.size() - ofs));
 		}
 	}
@@ -616,24 +624,28 @@ void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
 			}
 			auto release = instMan.lock()->getPitchSSGRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
 			}
-			ctr.appendUint8(static_cast<uint8_t>(instMan.lock()->getPitchSSGType(idx)));
+			switch (instMan.lock()->getPitchSSGType(idx)) {
+			case SequenceType::ABSOLUTE_SEQUENCE:	ctr.appendUint8(0x00);	break;
+			case SequenceType::RELATIVE_SEQUENCE:	ctr.appendUint8(0x02);	break;
+			default:												break;
+			}
 			ctr.writeUint16(ofs, static_cast<uint16_t>(ctr.size() - ofs));
 		}
 	}
@@ -641,33 +653,27 @@ void BankIO::saveBank(std::string path, std::vector<size_t> instNums,
 	ctr.writeUint32(instPropOfs, ctr.size() - instPropOfs);
 
 	ctr.writeUint32(eofOfs, ctr.size() - eofOfs);
-
-	if (!ctr.save(path)) throw FileOutputError(FileIO::FileType::BANK);
 }
 
-AbstractBank* BankIO::loadBank(std::string path)
+AbstractBank* BankIO::loadBank(BinaryContainer& ctr, std::string path)
 {
 	std::string ext = FileIO::getExtension(path);
-	if (ext.compare("wopn") == 0) return BankIO::loadWOPNFile(path);
-	if (ext.compare("btb") == 0) return BankIO::loadBTBFile(path);
-	throw FileInputError(FileIO::FileType::BANK);
+	if (ext.compare("wopn") == 0) return BankIO::loadWOPNFile(ctr);
+	if (ext.compare("btb") == 0) return BankIO::loadBTBFile(ctr);
+	throw FileInputError(FileIO::FileType::Bank);
 }
 
-AbstractBank* BankIO::loadBTBFile(std::string path)
+AbstractBank* BankIO::loadBTBFile(BinaryContainer& ctr)
 {
-	BinaryContainer ctr;
-
-	if (!ctr.load(path)) throw FileInputError(FileIO::FileType::BANK);
-
 	size_t globCsr = 0;
 	if (ctr.readString(globCsr, 16) != "BambooTrackerBnk")
-		throw FileCorruptionError(FileIO::FileType::BANK);
+		throw FileCorruptionError(FileIO::FileType::Bank);
 	globCsr += 16;
 	/*size_t eofOfs = */ctr.readUint32(globCsr);
 	globCsr += 4;
 	size_t fileVersion = ctr.readUint32(globCsr);
 	if (fileVersion > Version::ofBankFileInBCD())
-		throw FileVersionError(fileVersion, Version::ofApplicationInBCD(), FileIO::FileType::BANK);
+		throw FileVersionError(FileIO::FileType::Bank);
 	globCsr += 4;
 
 
@@ -675,7 +681,7 @@ AbstractBank* BankIO::loadBTBFile(std::string path)
 	std::vector<int> ids;
 	std::vector<std::string> names;
 	std::vector<BinaryContainer> instCtrs;
-	if (ctr.readString(globCsr, 8) != "INSTRMNT") throw FileCorruptionError(FileIO::FileType::BANK);
+	if (ctr.readString(globCsr, 8) != "INSTRMNT") throw FileCorruptionError(FileIO::FileType::Bank);
 	globCsr += 8;
 	size_t instOfs = ctr.readUint32(globCsr);
 	size_t instCsr = globCsr + 4;
@@ -703,7 +709,7 @@ AbstractBank* BankIO::loadBTBFile(std::string path)
 
 
 	/***** Instrument property section *****/
-	if (ctr.readString(globCsr, 8) != "INSTPROP") throw FileCorruptionError(FileIO::FileType::INST);
+	if (ctr.readString(globCsr, 8) != "INSTPROP") throw FileCorruptionError(FileIO::FileType::Inst);
 	globCsr += 8;
 	size_t instPropOfs = ctr.readUint32(globCsr);
 	BinaryContainer propCtr = ctr.getSubcontainer(globCsr + 4, instPropOfs - 4);
@@ -711,29 +717,16 @@ AbstractBank* BankIO::loadBTBFile(std::string path)
 	return new BtBank(std::move(ids), std::move(names), std::move(instCtrs), std::move(propCtr), fileVersion);
 }
 
-AbstractBank* BankIO::loadWOPNFile(std::string path)
+AbstractBank* BankIO::loadWOPNFile(BinaryContainer& ctr)
 {
 	struct WOPNDeleter {
 		void operator()(WOPNFile *x) { WOPN_Free(x); }
 	};
 
 	std::unique_ptr<WOPNFile, WOPNDeleter> wopn;
-
-	nowide::ifstream in(path, std::ios::binary);
-	in.seekg(0, std::ios::end);
-	std::streampos size = in.tellg();
-
-	if (!in)
-		throw FileInputError(FileIO::FileType::BANK);
-	else {
-		std::unique_ptr<char[]> buf(new char[size]);
-		in.seekg(0, std::ios::beg);
-		if (!in.read(buf.get(), size) || in.gcount() != size)
-			throw FileInputError(FileIO::FileType::BANK);
-		wopn.reset(WOPN_LoadBankFromMem(buf.get(), size, nullptr));
-		if (!wopn)
-			throw FileCorruptionError(FileIO::FileType::BANK);
-	}
+	wopn.reset(WOPN_LoadBankFromMem(const_cast<char*>(ctr.getPointer()), ctr.size(), nullptr));
+	if (!wopn)
+		throw FileCorruptionError(FileIO::FileType::Bank);
 
 	WopnBank *bank = new WopnBank(wopn.get());
 	wopn.release();
