@@ -1,5 +1,4 @@
 #include "binary_container.hpp"
-#include <nowide/fstream.hpp>
 #include <algorithm>
 #include <iterator>
 #include <utility>
@@ -42,31 +41,6 @@ bool BinaryContainer::isLittleEndian() const
 	return isLE_;
 }
 
-bool BinaryContainer::load(std::string path)
-{
-	try {
-		nowide::ifstream ifs(path, std::ios::binary);
-		buf_.resize(static_cast<size_t>(ifs.seekg(0, std::ios::end).tellg()));
-		ifs.seekg(0, std::ios::beg).read(&buf_[0], static_cast<std::streamsize>(buf_.size()));
-		return true;
-	}
-	catch (...) {
-		return false;
-	}
-}
-
-bool BinaryContainer::save(std::string path)
-{
-	try {
-		nowide::ofstream ofs(path, std::ios::binary);
-		ofs.write(&buf_[0], static_cast<std::streamsize>(buf_.size()));
-		return true;
-	}
-	catch (...) {
-		return false;
-	}
-}
-
 void BinaryContainer::appendInt8(const int8_t v)
 {
 	buf_.push_back(static_cast<char>(v));
@@ -123,6 +97,21 @@ void BinaryContainer::appendString(const std::string str)
 	std::copy(str.begin(), str.end(), std::back_inserter(buf_));
 }
 
+void BinaryContainer::appendArray(const uint8_t* array, size_t size)
+{
+	std::copy(array, array + size, std::back_inserter(buf_));
+}
+
+void BinaryContainer::appendVector(const std::vector<uint8_t> vec)
+{
+	std::copy(vec.begin(), vec.end(), std::back_inserter(buf_));
+}
+
+void BinaryContainer::appendVector(const std::vector<char> vec)
+{
+	std::copy(vec.begin(), vec.end(), std::back_inserter(buf_));
+}
+
 void BinaryContainer::writeInt8(size_t offset, const int8_t v)
 {
 	buf_.at(offset) = static_cast<char>(v);
@@ -230,6 +219,11 @@ BinaryContainer BinaryContainer::getSubcontainer(size_t offset, size_t length) c
 	return BinaryContainer(std::move(tmp));
 }
 
+const char* BinaryContainer::getPointer() const
+{
+	return &buf_[0];
+}
+
 void BinaryContainer::append(std::vector<char> a)
 {
 	if (isLE_)
