@@ -16,9 +16,6 @@ public:
 	void setEndian(bool isLittleEndian);
 	bool isLittleEndian() const;
 
-	bool load(std::string path);
-	bool save(std::string path);
-
 	void appendInt8(const int8_t v);
 	void appendUint8(const uint8_t v);
 	void appendInt16(const int16_t v);
@@ -27,6 +24,9 @@ public:
 	void appendUint32(const uint32_t v);
 	void appendChar(const char c);
 	void appendString(const std::string str);
+	void appendArray(const uint8_t* array, size_t size);
+	void appendVector(const std::vector<uint8_t> vec);
+	void appendVector(const std::vector<char> vec);
 
 	void writeInt8(size_t offset, const int8_t v);
 	void writeUint8(size_t offset, const uint8_t v);
@@ -48,6 +48,8 @@ public:
 
 	BinaryContainer getSubcontainer(size_t offset, size_t length) const;
 
+	const char* getPointer() const;
+
 private:
 	std::vector<char> buf_;
 	bool isLE_;
