@@ -11,10 +11,9 @@ public:
 
 	enum class FileType
 	{
-		MOD, INST, WAV, VGM, BANK, S98, UNKNOWN
+		Mod, Inst, WAV, VGM, Bank, S98, Unknown
 	};
 
-	static std::string fileTypeToString(const FileType type);
 	static std::string getExtension(const std::string path);
 	static FileType judgeFileTypeFromExtension(const std::string ext);
 
