@@ -1,17 +1,16 @@
 #include "module_io.hpp"
-#include <nowide/fstream.hpp>
+#include <string>
 #include "version.hpp"
 #include "file_io_error.hpp"
 #include "file_io.hpp"
 #include "pitch_converter.hpp"
+#include "effect.hpp"
 
 ModuleIO::ModuleIO() {}
 
-void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
+void ModuleIO::saveModule(BinaryContainer& ctr, std::weak_ptr<Module> mod,
 						  std::weak_ptr<InstrumentsManager> instMan)
 {
-	BinaryContainer ctr;
-
 	ctr.appendString("BambooTrackerMod");
 	size_t eofOfs = ctr.size();
 	ctr.appendUint32(0);	// Dummy EOF offset
@@ -38,6 +37,12 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 	ctr.appendUint32(mod.lock()->getTickFrequency());
 	ctr.appendUint32(mod.lock()->getStepHighlight1Distance());
 	ctr.appendUint32(mod.lock()->getStepHighlight2Distance());
+	MixerType mixType = mod.lock()->getMixerType();
+	ctr.appendUint8(static_cast<uint8_t>(mixType));
+	if (mixType == MixerType::CUSTOM) {
+		ctr.appendInt8(static_cast<int8_t>(mod.lock()->getCustomMixerFMLevel() * 10));
+		ctr.appendInt8(static_cast<int8_t>(mod.lock()->getCustomMixerSSGLevel() * 10));
+	}
 	ctr.writeUint32(modOfs, ctr.size() - modOfs);
 
 
@@ -103,7 +108,7 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 				ctr.appendUint8(instSSG->getPitchEnabled() ? tmp : (0x80 | tmp));
 				break;
 			}
-			case SoundSource::Drum:
+			case SoundSource::DRUM:
 				break;
 			}
 			ctr.writeUint32(iOfs, ctr.size() - iOfs);
@@ -227,7 +232,7 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 				  | static_cast<uint8_t>(instMan.lock()->getLFOFMparameter(idx, FMLFOParameter::AM1) << 4)
 				  | static_cast<uint8_t>(instMan.lock()->getLFOFMparameter(idx, FMLFOParameter::AMS));
 			ctr.appendUint8(tmp);
-			tmp = static_cast<uint8_t>(instMan.lock()->getLFOFMparameter(idx, FMLFOParameter::COUNT));
+			tmp = static_cast<uint8_t>(instMan.lock()->getLFOFMparameter(idx, FMLFOParameter::Count));
 			ctr.appendUint8(tmp);
 			ctr.writeUint8(ofs, static_cast<uint8_t>(ctr.size() - ofs));
 		}
@@ -257,18 +262,18 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 				}
 				auto release = instMan.lock()->getOperatorSequenceFMRelease(FileIO::ENV_FM_PARAMS[i], idx);
 				switch (release.type) {
-				case ReleaseType::NO_RELEASE:
+				case ReleaseType::NoRelease:
 					ctr.appendUint8(0x00);
 					break;
-				case ReleaseType::FIX:
+				case ReleaseType::FixedRelease:
 					ctr.appendUint8(0x01);
 					ctr.appendUint16(static_cast<uint16_t>(release.begin));
 					break;
-				case ReleaseType::ABSOLUTE:
+				case ReleaseType::AbsoluteRelease:
 					ctr.appendUint8(0x02);
 					ctr.appendUint16(static_cast<uint16_t>(release.begin));
 					break;
-				case ReleaseType::RELATIVE:
+				case ReleaseType::RelativeRelease:
 					ctr.appendUint8(0x03);
 					ctr.appendUint16(static_cast<uint16_t>(release.begin));
 					break;
@@ -302,24 +307,29 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			}
 			auto release = instMan.lock()->getArpeggioFMRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
 			}
-			ctr.appendUint8(static_cast<uint8_t>(instMan.lock()->getArpeggioFMType(idx)));
+			switch (instMan.lock()->getArpeggioFMType(idx)) {
+			case SequenceType::ABSOLUTE_SEQUENCE:	ctr.appendUint8(0x00);	break;
+			case SequenceType::FIXED_SEQUENCE:		ctr.appendUint8(0x01);	break;
+			case SequenceType::RELATIVE_SEQUENCE:	ctr.appendUint8(0x02);	break;
+			default:												break;
+			}
 			ctr.writeUint16(ofs, static_cast<uint16_t>(ctr.size() - ofs));
 		}
 	}
@@ -347,24 +357,28 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			}
 			auto release = instMan.lock()->getPitchFMRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
 			}
-			ctr.appendUint8(static_cast<uint8_t>(instMan.lock()->getPitchFMType(idx)));
+			switch (instMan.lock()->getPitchFMType(idx)) {
+			case SequenceType::ABSOLUTE_SEQUENCE:	ctr.appendUint8(0x00);	break;
+			case SequenceType::RELATIVE_SEQUENCE:	ctr.appendUint8(0x02);	break;
+			default:												break;
+			}
 			ctr.writeUint16(ofs, static_cast<uint16_t>(ctr.size() - ofs));
 		}
 	}
@@ -393,19 +407,19 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			}
 			auto release = instMan.lock()->getWaveFormSSGRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
@@ -438,19 +452,19 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			}
 			auto release = instMan.lock()->getToneNoiseSSGRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
@@ -485,19 +499,19 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			auto release = instMan.lock()->getEnvelopeSSGRelease(idx);
 
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
@@ -530,24 +544,29 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			}
 			auto release = instMan.lock()->getArpeggioSSGRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
 			}
-			ctr.appendUint8(static_cast<uint8_t>(instMan.lock()->getArpeggioSSGType(idx)));
+			switch (instMan.lock()->getArpeggioSSGType(idx)) {
+			case SequenceType::ABSOLUTE_SEQUENCE:	ctr.appendUint8(0x00);	break;
+			case SequenceType::FIXED_SEQUENCE:		ctr.appendUint8(0x01);	break;
+			case SequenceType::RELATIVE_SEQUENCE:	ctr.appendUint8(0x02);	break;
+			default:												break;
+			}
 			ctr.writeUint16(ofs, static_cast<uint16_t>(ctr.size() - ofs));
 		}
 	}
@@ -575,24 +594,28 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			}
 			auto release = instMan.lock()->getPitchSSGRelease(idx);
 			switch (release.type) {
-			case ReleaseType::NO_RELEASE:
+			case ReleaseType::NoRelease:
 				ctr.appendUint8(0x00);
 				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
-			case ReleaseType::FIX:
+			case ReleaseType::FixedRelease:
 				ctr.appendUint8(0x01);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::ABSOLUTE:
+			case ReleaseType::AbsoluteRelease:
 				ctr.appendUint8(0x02);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
-			case ReleaseType::RELATIVE:
+			case ReleaseType::RelativeRelease:
 				ctr.appendUint8(0x03);
 				ctr.appendUint16(static_cast<uint16_t>(release.begin));
 				break;
 			}
-			ctr.appendUint8(static_cast<uint8_t>(instMan.lock()->getPitchSSGType(idx)));
+			switch (instMan.lock()->getPitchSSGType(idx)) {
+			case SequenceType::ABSOLUTE_SEQUENCE:	ctr.appendUint8(0x00);	break;
+			case SequenceType::RELATIVE_SEQUENCE:	ctr.appendUint8(0x02);	break;
+			default:												break;
+			}
 			ctr.writeUint16(ofs, static_cast<uint16_t>(ctr.size() - ofs));
 		}
 	}
@@ -640,9 +663,9 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 		ctr.appendUint8(static_cast<uint8_t>(sng.getDefaultPatternSize()) - 1);
 		auto style = sng.getStyle();
 		switch (style.type) {
-		case SongType::STD:		ctr.appendUint8(0x00);	break;
-		case SongType::FMEX:	ctr.appendUint8(0x01);	break;
-		default:	throw FileOutputError(FileIO::FileType::MOD);
+		case SongType::Standard:		ctr.appendUint8(0x00);	break;
+		case SongType::FM3chExpanded:	ctr.appendUint8(0x01);	break;
+		default:	throw FileOutputError(FileIO::FileType::Mod);
 		}
 
 		// Track
@@ -715,29 +738,21 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 	ctr.writeUint32(songSecOfs, ctr.size() - songSecOfs);
 
 	ctr.writeUint32(eofOfs, ctr.size() - eofOfs);
-
-	mod.lock()->setFilePath(path);
-
-	if (!ctr.save(path)) throw FileOutputError(FileIO::FileType::MOD);
 }
 
-void ModuleIO::loadModule(std::string path, std::weak_ptr<Module> mod,
+void ModuleIO::loadModule(BinaryContainer& ctr, std::weak_ptr<Module> mod,
 						  std::weak_ptr<InstrumentsManager> instMan)
 {
-	BinaryContainer ctr;
-
-	if (!ctr.load(path)) throw FileInputError(FileIO::FileType::MOD);
-
 	size_t globCsr = 0;
 	if (ctr.readString(globCsr, 16) != "BambooTrackerMod")
-		throw FileCorruptionError(FileIO::FileType::MOD);
+		throw FileCorruptionError(FileIO::FileType::Mod);
 	globCsr += 16;
 	size_t eofOfs = ctr.readUint32(globCsr);
 	size_t eof = globCsr + eofOfs;
 	globCsr += 4;
 	size_t fileVersion = ctr.readUint32(globCsr);
 	if (fileVersion > Version::ofModuleFileInBCD())
-		throw FileVersionError(fileVersion, Version::ofApplicationInBCD(), FileIO::FileType::MOD);
+		throw FileVersionError(FileIO::FileType::Mod);
 	globCsr += 4;
 
 	while (globCsr < eof) {
@@ -752,10 +767,8 @@ void ModuleIO::loadModule(std::string path, std::weak_ptr<Module> mod,
 		else if (ctr.readString(globCsr, 8) == "SONG    ")
 			globCsr = loadSongSectionInModule(mod, ctr, globCsr + 8, fileVersion);
 		else
-			throw FileCorruptionError(FileIO::FileType::MOD);
+			throw FileCorruptionError(FileIO::FileType::Mod);
 	}
-
-	mod.lock()->setFilePath(path);
 }
 
 size_t ModuleIO::loadModuleSectionInModule(std::weak_ptr<Module> mod, BinaryContainer& ctr,
@@ -798,6 +811,17 @@ size_t ModuleIO::loadModuleSectionInModule(std::weak_ptr<Module> mod, BinaryCont
 	else {
 		mod.lock()->setStepHighlight2Distance(mod.lock()->getStepHighlight1Distance() * 4);
 	}
+	if (version >= Version::toBCD(1, 3, 0)) {
+		auto mixType = static_cast<MixerType>(ctr.readUint8(modCsr++));
+		mod.lock()->setMixerType(mixType);
+		if (mixType == MixerType::CUSTOM) {
+			mod.lock()->setCustomMixerFMLevel(ctr.readInt8(modCsr++) / 10.0);
+			mod.lock()->setCustomMixerSSGLevel(ctr.readInt8(modCsr++) / 10.0);
+		}
+	}
+	else {
+		mod.lock()->setMixerType(MixerType::UNSPECIFIED);
+	}
 
 	return globCsr + modOfs;
 }
@@ -899,7 +923,7 @@ size_t ModuleIO::loadInstrumentSectionInModule(std::weak_ptr<InstrumentsManager>
 			break;
 		}
 		default:
-			throw FileCorruptionError(FileIO::FileType::MOD);
+			throw FileCorruptionError(FileIO::FileType::Mod);
 		}
 		instCsr += iOfs;
 	}
@@ -1023,7 +1047,7 @@ size_t ModuleIO::loadInstrumentPropertySectionInModule(std::weak_ptr<Instruments
 				instMan.lock()->setLFOFMParameter(idx, FMLFOParameter::AM3, (tmp & 0x40) ? true : false);
 				instMan.lock()->setLFOFMParameter(idx, FMLFOParameter::AM4, (tmp & 0x80) ? true : false);
 				tmp = ctr.readUint8(csr++);
-				instMan.lock()->setLFOFMParameter(idx, FMLFOParameter::COUNT, tmp);
+				instMan.lock()->setLFOFMParameter(idx, FMLFOParameter::Count, tmp);
 				instPropCsr += ofs;
 			}
 			break;
@@ -1367,22 +1391,43 @@ size_t ModuleIO::loadInstrumentPropertySectionInModule(std::weak_ptr<Instruments
 				}
 				switch (ctr.readUint8(csr++)) {
 				case 0x00:	// No release
-					instMan.lock()->setArpeggioFMRelease(idx, ReleaseType::NO_RELEASE, -1);
+					instMan.lock()->setArpeggioFMRelease(idx, ReleaseType::NoRelease, -1);
 					break;
-				case 0x01:	// Fix
+				case 0x01:	// Fixed
 				{
 					uint16_t pos = ctr.readUint16(csr);
 					csr += 2;
-					// Release point check (prevents a bug; see rerrahkr/BambooTracker issue #11)
-					if (pos < seqLen) instMan.lock()->setArpeggioFMRelease(idx, ReleaseType::FIX, pos);
-					else instMan.lock()->setArpeggioFMRelease(idx, ReleaseType::NO_RELEASE, -1);
+					// Release point check (prevents a bug)
+					// https://github.com/rerrahkr/BambooTracker/issues/11
+					if (pos < seqLen) instMan.lock()->setArpeggioFMRelease(idx, ReleaseType::FixedRelease, pos);
+					else instMan.lock()->setArpeggioFMRelease(idx, ReleaseType::NoRelease, -1);
 					break;
 				}
 				default:
-					throw FileCorruptionError(FileIO::FileType::MOD);
+					throw FileCorruptionError(FileIO::FileType::Mod);
 				}
 				if (version >= Version::toBCD(1, 0, 1)) {
-					instMan.lock()->setArpeggioFMType(idx, ctr.readUint8(csr++));
+					switch (ctr.readUint8(csr++)) {
+					case 0x00:	// Absolute
+						instMan.lock()->setArpeggioFMType(idx, SequenceType::ABSOLUTE_SEQUENCE);
+						break;
+					case 0x01:	// Fixed
+						instMan.lock()->setArpeggioFMType(idx, SequenceType::FIXED_SEQUENCE);
+						break;
+					case 0x02:	// Relative
+						instMan.lock()->setArpeggioFMType(idx, SequenceType::RELATIVE_SEQUENCE);
+						break;
+					default:
+						if (version < Version::toBCD(1, 3, 2)) {
+							// Recover deep clone bug
+							// https://github.com/rerrahkr/BambooTracker/issues/170
+							instMan.lock()->setArpeggioFMType(idx, SequenceType::ABSOLUTE_SEQUENCE);
+							break;
+						}
+						else {
+							throw FileCorruptionError(FileIO::FileType::Mod);
+						}
+					}
 				}
 
 				instPropCsr += ofs;
@@ -1425,22 +1470,40 @@ size_t ModuleIO::loadInstrumentPropertySectionInModule(std::weak_ptr<Instruments
 
 				switch (ctr.readUint8(csr++)) {
 				case 0x00:	// No release
-					instMan.lock()->setPitchFMRelease(idx, ReleaseType::NO_RELEASE, -1);
+					instMan.lock()->setPitchFMRelease(idx, ReleaseType::NoRelease, -1);
 					break;
-				case 0x01:	// Fix
+				case 0x01:	// Fixed
 				{
 					uint16_t pos = ctr.readUint16(csr);
 					csr += 2;
-					// Release point check (prevents a bug; see rerrahkr/BambooTracker issue #11)
-					if (pos < seqLen) instMan.lock()->setPitchFMRelease(idx, ReleaseType::FIX, pos);
-					else instMan.lock()->setPitchFMRelease(idx, ReleaseType::NO_RELEASE, -1);
+					// Release point check (prevents a bug)
+					// https://github.com/rerrahkr/BambooTracker/issues/11
+					if (pos < seqLen) instMan.lock()->setPitchFMRelease(idx, ReleaseType::FixedRelease, pos);
+					else instMan.lock()->setPitchFMRelease(idx, ReleaseType::NoRelease, -1);
 					break;
 				}
 				default:
-					throw FileCorruptionError(FileIO::FileType::MOD);
+					throw FileCorruptionError(FileIO::FileType::Mod);
 				}
 				if (version >= Version::toBCD(1, 0, 1)) {
-					instMan.lock()->setPitchFMType(idx, ctr.readUint8(csr++));
+					switch (ctr.readUint8(csr++)) {
+					case 0x00:	// Absolute
+						instMan.lock()->setPitchFMType(idx, SequenceType::ABSOLUTE_SEQUENCE);
+						break;
+					case 0x02:	// Relative
+						instMan.lock()->setPitchFMType(idx, SequenceType::RELATIVE_SEQUENCE);
+						break;
+					default:
+						if (version < Version::toBCD(1, 3, 2)) {
+							// Recover deep clone bug
+							// https://github.com/rerrahkr/BambooTracker/issues/170
+							instMan.lock()->setPitchFMType(idx, SequenceType::ABSOLUTE_SEQUENCE);
+							break;
+						}
+						else {
+							throw FileCorruptionError(FileIO::FileType::Mod);
+						}
+					}
 				}
 
 				instPropCsr += ofs;
@@ -1497,19 +1560,20 @@ size_t ModuleIO::loadInstrumentPropertySectionInModule(std::weak_ptr<Instruments
 
 				switch (ctr.readUint8(csr++)) {
 				case 0x00:	// No release
-					instMan.lock()->setWaveFormSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					instMan.lock()->setWaveFormSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
-				case 0x01:	// Fix
+				case 0x01:	// Fixed
 				{
 					uint16_t pos = ctr.readUint16(csr);
 					csr += 2;
-					// Release point check (prevents a bug; see rerrahkr/BambooTracker issue #11)
-					if (pos < seqLen) instMan.lock()->setWaveFormSSGRelease(idx, ReleaseType::FIX, pos);
-					else instMan.lock()->setWaveFormSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					// Release point check (prevents a bug)
+					// https://github.com/rerrahkr/BambooTracker/issues/11
+					if (pos < seqLen) instMan.lock()->setWaveFormSSGRelease(idx, ReleaseType::FixedRelease, pos);
+					else instMan.lock()->setWaveFormSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
 				}
 				default:
-					throw FileCorruptionError(FileIO::FileType::MOD);
+					throw FileCorruptionError(FileIO::FileType::Mod);
 				}
 				if (version >= Version::toBCD(1, 0, 1)) {
 					++csr;	// Skip sequence type
@@ -1532,6 +1596,12 @@ size_t ModuleIO::loadInstrumentPropertySectionInModule(std::weak_ptr<Instruments
 				for (uint16_t l = 0; l < seqLen; ++l) {
 					uint16_t data = ctr.readUint16(csr);
 					csr += 2;
+					if (version < Version::toBCD(1, 3, 1)) {
+						if (data > 0) {
+							uint16_t tmp = data - 1;
+							data = tmp / 32 * 32 + (31 - tmp % 32) + 1;
+						}
+					}
 					if (version < Version::toBCD(1, 2, 0)) csr += 2;
 					if (l == 0)
 						instMan.lock()->setToneNoiseSSGSequenceCommand(idx, 0, data, 0);
@@ -1555,19 +1625,20 @@ size_t ModuleIO::loadInstrumentPropertySectionInModule(std::weak_ptr<Instruments
 
 				switch (ctr.readUint8(csr++)) {
 				case 0x00:	// No release
-					instMan.lock()->setToneNoiseSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					instMan.lock()->setToneNoiseSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
-				case 0x01:	// Fix
+				case 0x01:	// Fixed
 				{
 					uint16_t pos = ctr.readUint16(csr);
 					csr += 2;
-					// Release point check (prevents a bug; see rerrahkr/BambooTracker issue #11)
-					if (pos < seqLen) instMan.lock()->setToneNoiseSSGRelease(idx, ReleaseType::FIX, pos);
-					else instMan.lock()->setToneNoiseSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					// Release point check (prevents a bug)
+					// https://github.com/rerrahkr/BambooTracker/issues/11
+					if (pos < seqLen) instMan.lock()->setToneNoiseSSGRelease(idx, ReleaseType::FixedRelease, pos);
+					else instMan.lock()->setToneNoiseSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
 				}
 				default:
-					throw FileCorruptionError(FileIO::FileType::MOD);
+					throw FileCorruptionError(FileIO::FileType::Mod);
 				}
 				if (version >= Version::toBCD(1, 0, 1)) {
 					++csr;	// Skip sequence type
@@ -1621,35 +1692,36 @@ size_t ModuleIO::loadInstrumentPropertySectionInModule(std::weak_ptr<Instruments
 
 				switch (ctr.readUint8(csr++)) {
 				case 0x00:	// No release
-					instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
-					// Release point check (prevents a bug; see rerrahkr/BambooTracker issue #11)
-				case 0x01:	// Fix
+					// Release point check (prevents a bug)
+					// https://github.com/rerrahkr/BambooTracker/issues/11
+				case 0x01:	// Fixed
 				{
 					uint16_t pos = ctr.readUint16(csr);
 					csr += 2;
-					if (pos < seqLen) instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::FIX, pos);
-					else instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					if (pos < seqLen) instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::FixedRelease, pos);
+					else instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
 				}
 				case 0x02:	// Absolute
 				{
 					uint16_t pos = ctr.readUint16(csr);
 					csr += 2;
-					if (pos < seqLen) instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::ABSOLUTE, pos);
-					else instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					if (pos < seqLen) instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::AbsoluteRelease, pos);
+					else instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
 				}
 				case 0x03:	// Relative
 				{
 					uint16_t pos = ctr.readUint16(csr);
 					csr += 2;
-					if (pos < seqLen) instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::RELATIVE, pos);
-					else instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					if (pos < seqLen) instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::RelativeRelease, pos);
+					else instMan.lock()->setEnvelopeSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
 				}
 				default:
-					throw FileCorruptionError(FileIO::FileType::MOD);
+					throw FileCorruptionError(FileIO::FileType::Mod);
 				}
 				if (version >= Version::toBCD(1, 0, 1)) {
 					++csr;	// Skip sequence type
@@ -1695,22 +1767,43 @@ size_t ModuleIO::loadInstrumentPropertySectionInModule(std::weak_ptr<Instruments
 
 				switch (ctr.readUint8(csr++)) {
 				case 0x00:	// No release
-					instMan.lock()->setArpeggioSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					instMan.lock()->setArpeggioSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
-				case 0x01:	// Fix
+				case 0x01:	// Fixed
 				{
 					uint16_t pos = ctr.readUint16(csr);
 					csr += 2;
-					// Release point check (prevents a bug; see rerrahkr/BambooTracker issue #11)
-					if (pos < seqLen) instMan.lock()->setArpeggioSSGRelease(idx, ReleaseType::FIX, pos);
-					else instMan.lock()->setArpeggioSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					// Release point check (prevents a bug)
+					// https://github.com/rerrahkr/BambooTracker/issues/11
+					if (pos < seqLen) instMan.lock()->setArpeggioSSGRelease(idx, ReleaseType::FixedRelease, pos);
+					else instMan.lock()->setArpeggioSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
 				}
 				default:
-					throw FileCorruptionError(FileIO::FileType::MOD);
+					throw FileCorruptionError(FileIO::FileType::Mod);
 				}
 				if (version >= Version::toBCD(1, 0, 1)) {
-					instMan.lock()->setArpeggioSSGType(idx, ctr.readUint8(csr++));
+					switch (ctr.readUint8(csr++)) {
+					case 0x00:	// Absolute
+						instMan.lock()->setArpeggioSSGType(idx, SequenceType::ABSOLUTE_SEQUENCE);
+						break;
+					case 0x01:	// Fixed
+						instMan.lock()->setArpeggioSSGType(idx, SequenceType::FIXED_SEQUENCE);
+						break;
+					case 0x02:	// Relative
+						instMan.lock()->setArpeggioSSGType(idx, SequenceType::RELATIVE_SEQUENCE);
+						break;
+					default:
+						if (version < Version::toBCD(1, 3, 2)) {
+							// Recover deep clone bug
+							// https://github.com/rerrahkr/BambooTracker/issues/170
+							instMan.lock()->setArpeggioSSGType(idx, SequenceType::ABSOLUTE_SEQUENCE);
+							break;
+						}
+						else {
+							throw FileCorruptionError(FileIO::FileType::Mod);
+						}
+					}
 				}
 
 				instPropCsr += ofs;
@@ -1753,22 +1846,40 @@ size_t ModuleIO::loadInstrumentPropertySectionInModule(std::weak_ptr<Instruments
 
 				switch (ctr.readUint8(csr++)) {
 				case 0x00:	// No release
-					instMan.lock()->setPitchSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					instMan.lock()->setPitchSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
-				case 0x01:	// Fix
+				case 0x01:	// Fixed
 				{
 					uint16_t pos = ctr.readUint16(csr);
 					csr += 2;
-					// Release point check (prevents a bug; see rerrahkr/BambooTracker issue #11)
-					if (pos < seqLen) instMan.lock()->setPitchSSGRelease(idx, ReleaseType::FIX, pos);
-					else instMan.lock()->setPitchSSGRelease(idx, ReleaseType::NO_RELEASE, -1);
+					// Release point check (prevents a bug)
+					// https://github.com/rerrahkr/BambooTracker/issues/11
+					if (pos < seqLen) instMan.lock()->setPitchSSGRelease(idx, ReleaseType::FixedRelease, pos);
+					else instMan.lock()->setPitchSSGRelease(idx, ReleaseType::NoRelease, -1);
 					break;
 				}
 				default:
-					throw FileCorruptionError(FileIO::FileType::MOD);
+					throw FileCorruptionError(FileIO::FileType::Mod);
 				}
 				if (version >= Version::toBCD(1, 0, 1)) {
-					instMan.lock()->setPitchSSGType(idx, ctr.readUint8(csr++));
+					switch (ctr.readUint8(csr++)) {
+					case 0x00:	// Absolute
+						instMan.lock()->setPitchSSGType(idx, SequenceType::ABSOLUTE_SEQUENCE);
+						break;
+					case 0x02:	// Relative
+						instMan.lock()->setPitchSSGType(idx, SequenceType::RELATIVE_SEQUENCE);
+						break;
+					default:
+						if (version < Version::toBCD(1, 3, 2)) {
+							// Recover deep clone bug
+							// https://github.com/rerrahkr/BambooTracker/issues/170
+							instMan.lock()->setPitchSSGType(idx, SequenceType::ABSOLUTE_SEQUENCE);
+							break;
+						}
+						else {
+							throw FileCorruptionError(FileIO::FileType::Mod);
+						}
+					}
 				}
 
 				instPropCsr += ofs;
@@ -1776,7 +1887,7 @@ size_t ModuleIO::loadInstrumentPropertySectionInModule(std::weak_ptr<Instruments
 			break;
 		}
 		default:
-			throw FileCorruptionError(FileIO::FileType::MOD);
+			throw FileCorruptionError(FileIO::FileType::Mod);
 		}
 	}
 
@@ -1820,19 +1931,19 @@ size_t ModuleIO::loadInstrumentPropertyOperatorSequence(FMEnvelopeParameter para
 
 	switch (ctr.readUint8(csr++)) {
 	case 0x00:	// No release
-		instMan.lock()->setOperatorSequenceFMRelease(param, idx, ReleaseType::NO_RELEASE, -1);
+		instMan.lock()->setOperatorSequenceFMRelease(param, idx, ReleaseType::NoRelease, -1);
 		break;
-	case 0x01:	// Fix
+	case 0x01:	// Fixed
 	{
 		uint16_t pos = ctr.readUint16(csr);
 		csr += 2;
 		// Release point check (prevents a bug; see rerrahkr/BambooTracker issue #11)
-		if (pos < seqLen) instMan.lock()->setOperatorSequenceFMRelease(param, idx, ReleaseType::FIX, pos);
-		else instMan.lock()->setOperatorSequenceFMRelease(param, idx, ReleaseType::NO_RELEASE, -1);
+		if (pos < seqLen) instMan.lock()->setOperatorSequenceFMRelease(param, idx, ReleaseType::FixedRelease, pos);
+		else instMan.lock()->setOperatorSequenceFMRelease(param, idx, ReleaseType::NoRelease, -1);
 		break;
 	}
 	default:
-		throw FileCorruptionError(FileIO::FileType::MOD);
+		throw FileCorruptionError(FileIO::FileType::Mod);
 	}
 
 	if (version >= Version::toBCD(1, 0, 1)) {
@@ -1893,18 +2004,18 @@ size_t ModuleIO::loadSongSectionInModule(std::weak_ptr<Module> mod, BinaryContai
 		switch (ctr.readUint8(scsr++)) {
 		case 0x00:	// Standard
 		{
-			mod.lock()->addSong(idx, SongType::STD, title, isTempo,
+			mod.lock()->addSong(idx, SongType::Standard, title, isTempo,
 								static_cast<int>(tempo), groove, static_cast<int>(speed), ptnSize);
 			break;
 		}
 		case 0x01:	// FM3ch expanded
 		{
-			mod.lock()->addSong(idx, SongType::FMEX, title, isTempo,
+			mod.lock()->addSong(idx, SongType::FM3chExpanded, title, isTempo,
 								static_cast<int>(tempo), groove, static_cast<int>(speed), ptnSize);
 			break;
 		}
 		default:
-			throw FileCorruptionError(FileIO::FileType::MOD);
+			throw FileCorruptionError(FileIO::FileType::Mod);
 		}
 		auto& song = mod.lock()->getSong(idx);
 		while (scsr < songCsr) {
@@ -1926,6 +2037,7 @@ size_t ModuleIO::loadSongSectionInModule(std::weak_ptr<Module> mod, BinaryContai
 			if (version >= Version::toBCD(1, 2, 1)) {
 				track.setEffectDisplayWidth(ctr.readUint8(tcsr++));
 			}
+			SoundSource sndsrc = track.getAttribute().source;
 
 			// Pattern
 			while (tcsr < trackEnd) {
@@ -1956,26 +2068,58 @@ size_t ModuleIO::loadSongSectionInModule(std::weak_ptr<Module> mod, BinaryContai
 					}
 					if (eventFlag & 0x0002)	step.setInstrumentNumber(ctr.readUint8(pcsr++));
 					if (eventFlag & 0x0004)	step.setVolume(ctr.readUint8(pcsr++));
+					EffectType efftype = EffectType::NoEffect;
 					if (eventFlag & 0x0008)	{
-						step.setEffectID(0, ctr.readString(pcsr, 2));
+						std::string id = ctr.readString(pcsr, 2);
+						step.setEffectID(0, id);
+						efftype = Effect::toEffectType(sndsrc, id);
 						pcsr += 2;
 					}
-					if (eventFlag & 0x0010)	step.setEffectValue(0, ctr.readUint8(pcsr++));
+					if (eventFlag & 0x0010)	{
+						int v = ctr.readUint8(pcsr++);
+						if (version < Version::toBCD(1, 3, 1) && efftype == EffectType::NoisePitch && v < 32)
+							v = 31 - v;
+						step.setEffectValue(0, v);
+					}
+					efftype = EffectType::NoEffect;
 					if (eventFlag & 0x0020)	{
-						step.setEffectID(1, ctr.readString(pcsr, 2));
+						std::string id = ctr.readString(pcsr, 2);
+						step.setEffectID(1, id);
+						efftype = Effect::toEffectType(sndsrc, id);
 						pcsr += 2;
 					}
-					if (eventFlag & 0x0040)	step.setEffectValue(1, ctr.readUint8(pcsr++));
+					if (eventFlag & 0x0040)	{
+						int v = ctr.readUint8(pcsr++);
+						if (version < Version::toBCD(1, 3, 1) && efftype == EffectType::NoisePitch && v < 32)
+							v = 31 - v;
+						step.setEffectValue(1, v);
+					}
+					efftype = EffectType::NoEffect;
 					if (eventFlag & 0x0080)	{
-						step.setEffectID(2, ctr.readString(pcsr, 2));
+						std::string id = ctr.readString(pcsr, 2);
+						step.setEffectID(2, id);
+						efftype = Effect::toEffectType(sndsrc, id);
 						pcsr += 2;
 					}
-					if (eventFlag & 0x0100)	step.setEffectValue(2, ctr.readUint8(pcsr++));
+					if (eventFlag & 0x0100)	{
+						int v = ctr.readUint8(pcsr++);
+						if (version < Version::toBCD(1, 3, 1) && efftype == EffectType::NoisePitch && v < 32)
+							v = 31 - v;
+						step.setEffectValue(2, v);
+					}
+					efftype = EffectType::NoEffect;
 					if (eventFlag & 0x0200)	{
-						step.setEffectID(3, ctr.readString(pcsr, 2));
+						std::string id = ctr.readString(pcsr, 2);
+						step.setEffectID(3, id);
+						efftype = Effect::toEffectType(sndsrc, id);
 						pcsr += 2;
 					}
-					if (eventFlag & 0x0400)	step.setEffectValue(3, ctr.readUint8(pcsr++));
+					if (eventFlag & 0x0400)	{
+						int v = ctr.readUint8(pcsr++);
+						if (version < Version::toBCD(1, 3, 1) && efftype == EffectType::NoisePitch && v < 32)
+							v = 31 - v;
+						step.setEffectValue(3, v);
+					}
 				}
 			}
 
@@ -1985,14 +2129,3 @@ size_t ModuleIO::loadSongSectionInModule(std::weak_ptr<Module> mod, BinaryContai
 
 	return globCsr + songOfs;
 }
-
-void ModuleIO::backupModule(std::string path)
-{
-	try {
-		nowide::ifstream ifs(path, std::ios::binary);
-		nowide::ofstream ofs(path + ".bak", std::ios::binary);
-		ofs << ifs.rdbuf();
-	} catch (...) {
-		throw FileOutputError(FileIO::FileType::MOD);
-	}
-}
