@@ -11,7 +11,10 @@ Module::Module(std::string filePath, std::string title, std::string author, std:
 	  comment_(comment),
 	  tickFreq_(tickFreq),
 	  stepHl1Dist_(4),
-	  stepHl2Dist_(16)
+	  stepHl2Dist_(16),
+	  mixType_(MixerType::PC_9821_PC_9801_86),
+	  customLevelFM_(0),
+	  customLevelSSG_(0)
 {
 	songs_.emplace_back(0);
 	grooves_.emplace_back();
@@ -107,6 +110,36 @@ size_t Module::getGrooveCount() const
 	return grooves_.size();
 }
 
+void Module::setMixerType(MixerType type)
+{
+	mixType_ = type;
+}
+
+MixerType Module::getMixerType() const
+{
+	return mixType_;
+}
+
+void Module::setCustomMixerFMLevel(double level)
+{
+	customLevelFM_ = level;
+}
+
+double Module::getCustomMixerFMLevel() const
+{
+	return customLevelFM_;
+}
+
+void Module::setCustomMixerSSGLevel(double level)
+{
+	customLevelSSG_ = level;
+}
+
+double Module::getCustomMixerSSGLevel() const
+{
+	return customLevelSSG_;
+}
+
 void Module::addSong(SongType songType, std::string title)
 {
 	int n = static_cast<int>(songs_.size());
@@ -175,9 +208,9 @@ Groove& Module::getGroove(int num)
 	return grooves_.at(static_cast<size_t>(num));
 }
 
-std::set<int> Module::getRegisterdInstruments() const
+std::unordered_set<int> Module::getRegisterdInstruments() const
 {
-	std::set<int> set;
+	std::unordered_set<int> set;
 	for (auto& song : songs_) {
 		for (auto& n : song.getRegisteredInstruments()) {
 			set.insert(n);
@@ -190,3 +223,8 @@ void Module::clearUnusedPatterns()
 {
 	for (auto& song : songs_) song.clearUnusedPatterns();
 }
+
+void Module::replaceDuplicateInstrumentsInPatterns(std::unordered_map<int, int> map)
+{
+	for (auto& song : songs_) song.replaceDuplicateInstrumentsInPatterns(map);
+}
