@@ -1,8 +1,9 @@
 #pragma once
 
 #include <vector>
-#include <set>
+#include <unordered_set>
 #include <string>
+#include <unordered_map>
 #include "track.hpp"
 #include "misc.hpp"
 
@@ -11,7 +12,7 @@ struct SongStyle;
 class Song
 {
 public:
-	Song(int number, SongType songType = SongType::STD, std::string title = u8"", bool isUsedTempo = true,
+	Song(int number, SongType songType = SongType::Standard, std::string title = u8"", bool isUsedTempo = true,
 		 int tempo = 150, int groove = 0, int speed = 6, size_t defaultPatternSize = 64);
 
 	void setNumber(int n);
@@ -41,9 +42,10 @@ public:
 	void deleteOrder(int order);
 	void swapOrder(int a, int b);
 
-	std::set<int> getRegisteredInstruments() const;
+	std::unordered_set<int> getRegisteredInstruments() const;
 
 	void clearUnusedPatterns();
+	void replaceDuplicateInstrumentsInPatterns(std::unordered_map<int, int> map);
 
 private:
 	int num_;
