@@ -88,9 +88,9 @@ std::vector<int> Track::getEditedPatternIndices() const
 	return list;
 }
 
-std::set<int> Track::getRegisteredInstruments() const
+std::unordered_set<int> Track::getRegisteredInstruments() const
 {
-	std::set<int> set;
+	std::unordered_set<int> set;
 	for (auto& pattern : patterns_) {
 		for (auto& n : pattern.getRegisteredInstruments()) {
 			set.insert(n);
@@ -151,3 +151,18 @@ void Track::clearUnusedPatterns()
 			patterns_[i].clear();
 	}
 }
+
+void Track::replaceDuplicateInstrumentsInPatterns(std::unordered_map<int, int> map)
+{
+	for (size_t i = 0; i < 256; ++i) {
+		Pattern& pattern = patterns_[i];
+		if (pattern.existCommand()) {
+			for (size_t i = 0; i < pattern.getSize(); ++i) {
+				Step& step = pattern.getStep(static_cast<int>(i));
+				int inst = step.getInstrumentNumber();
+				if (map.count(inst)) step.setInstrumentNumber(map[inst]);
+			}
+		}
+
+	}
+}
