@@ -1,8 +1,9 @@
 #pragma once
 
 #include <vector>
-#include <set>
+#include <unordered_set>
 #include <memory>
+#include <unordered_map>
 #include "pattern.hpp"
 #include "misc.hpp"
 
@@ -22,7 +23,7 @@ public:
 	int searchFirstUneditedUnusedPattern() const;
 	int clonePattern(int num);
 	std::vector<int> getEditedPatternIndices() const;
-	std::set<int> getRegisteredInstruments() const;
+	std::unordered_set<int> getRegisteredInstruments() const;
 
 	void registerPatternToOrder(int order, int pattern);
 	void insertOrderBelow(int order);
@@ -35,6 +36,7 @@ public:
 	size_t getEffectDisplayWidth() const;
 
 	void clearUnusedPatterns();
+	void replaceDuplicateInstrumentsInPatterns(std::unordered_map<int, int> map);
 
 private:
 	std::unique_ptr<TrackAttribute> attrib_;
