@@ -12,14 +12,13 @@ public:
 	~Timer();
 
 	void setFunction(std::function<void()> func);
-	void setInterval(const int milisec);
+	void setInterval(const int microsec);
 
 	void start();
 	void stop();
 
 private:
 	std::atomic<int> time_;
-	const int checkTime_;
 	std::function<void()> func_;
 	std::thread thread_;
 	std::atomic_bool isContinue_;
