@@ -48,10 +48,23 @@ void TickCounter::setGroove(std::vector<int> seq)
 	if (nextGroovePos_ != -1) nextGroovePos_ = 0;
 }
 
-void TickCounter::setGrooveEnebled(bool enabled)
+void TickCounter::setGrooveTrigger(GrooveTrigger trigger)
 {
-	nextGroovePos_ = enabled ? (static_cast<int>(grooves_.size()) - 1) : -1;
-	resetRest();
+	switch (trigger) {
+	case GrooveTrigger::ValidByGlobal:
+		nextGroovePos_ = static_cast<int>(grooves_.size()) - 1;
+		resetRest();
+		break;
+	case GrooveTrigger::ValidByLocal:
+		nextGroovePos_ = 0;
+		resetRest();
+		--restTickToNextStep_;	// Count down by step head
+		break;
+	case GrooveTrigger::Invalid:
+		nextGroovePos_ = -1;
+		resetRest();
+		break;
+	}
 }
 
 bool TickCounter::getGrooveEnabled() const
@@ -104,6 +117,7 @@ void TickCounter::resetRest()
 		tickDifSum_ += tickDif_;
 		int castedTickDifSum = static_cast<int>(tickDifSum_);
 		restTickToNextStep_ = defStepSize_ + castedTickDifSum;
+		if (restTickToNextStep_ < 1) restTickToNextStep_ = 1;	// Prevent wait count changing to 0 (freeze)
 		tickDifSum_ -= castedTickDifSum;
 	}
 	else {
